*! version 1.0.5  13nov2008  by Marc Muendler muendler@ucsd.edu

cd "$rootslct"
clear
set matsize 400
set mem 400m
set more off

capture mkdir "$rootslct/tex/pop"
capture mkdir "$rootslct/tex/pop/pt$par-af$aff"  /* Directories not affected if they exist */

capture log close
log using "logs/reg-pop-pattern-ger-pt$par-af$aff-quarts.log", replace

foreach tlogyear in 1998 1999 2000 2001  {

tempfile pop`tlogyear'
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
local selyr = substr("`selyear'",3,2)

*----------------------following code identical to #reg-pop-pattern-ger.do------------------------------------------------------
*-----substitute: `tlogyear' for 2000, `tlogyr' for 00, ${yrdiff} for 4, `selyear' for 1996, `selyr' for 96, $dpref/ for $dp/---

* external files
tempfile secfix isocntry naceconc iso3buba quartile quartstr
global secfix "`secfix'"
use "$root/conc/sector-conc-nace", clear
sort buba_code
save `naceconc'
use "$root/conc/fdi-iso-country", clear
sort buba
compress
save `isocntry'
do "$dpref/#sector-definitions.do"
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'

use "$rootslct/tex/desc/quarts/$waglvl-quartiles", clear
sort country
save `quartile'
use "$rootslct/tex/desc/quarts/$waglvl-quartiles", clear
decode quartile, generate(quartstr)
drop quartile
rename country bubakey
sort bubakey
save `quartstr'

local share $share

use "$root/Xdata/affils-outwfdi96-01-eur-03mar2006", clear

* rename bg share
keep firmid affil2id year share sec1 sec2_fix country cntrygrp
order firmid affil2id year share sec1 sec2_fix country cntrygrp
sort firmid affil2id year
count

* FROM #bemfiles.do
keep if year==`tlogyear' | year==`selyear'
count

* FROM prep-parent-hostcntry-data-selct.do
keep if share>`share'
count
* country quartile definitions (different from swe-ger-conc.do)
foreach var in country {
    * tab `var'
    rename `var' bubakey  
    sort bubakey 
    merge bubakey using "`quartstr'", nokeep
    count if _m~=3 & bubakey~=.
    if `r(N)' > 0 {
        disp in red "Incomplete country concordance"
        * STOP
        }
    rename bubakey `var'
    drop _merge
    }
label var quartstr "Country group of affiliate"
sort firmid affil2id year
* sector and country resetting (similar to prep-summarize-affils.do)
* do "$dpref/#sector-country-resetting.do"  // country resetting not possible; copied code for sector resetting follows
decode sec1, generate(sec1_fix)
drop sec1
foreach var in sec1 sec2 {
  rename `var'_fix buba_code_3ltr
  sort buba_code_3ltr
  merge buba_code_3ltr using ${secfix}, nokeep
  tab _merge
  drop _merge buba_code_3ltr
  rename sec_bem `var'_bem
  rename sec_aggbem `var'_aggbem
  }
 qui do "$root/conc/secbem.do"
 label values sec1_bem secbem
 label values sec2_bem secbem
 qui do "$root/conc/sec7ltr.do"
 label values sec1_aggbem sec7ltr
 label values sec2_aggbem sec7ltr
 encode quartstr, generate(quartile) label(quarts)
 drop quartstr
 label var quartile "Country group of affiliate"
* affiliate sector selection
if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$aff" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "$aff" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }
count

* host country aggregation 
sort firmid affil2id year quartile
bysort firmid: gen byte _sameaff = 1 if affil2id==affil2id[_n-1]
egen sameaff = sum(_sameaff), by(firmid year quartile)
order firmid affil2id year quartile sameaff _sameaff
collapse (count) numaffil=affil2id (max) sec1_bem sec1_aggbem sameaff, by (firmid country year quartile) fast
sort firmid country year quartile
bysort firmid: gen byte _samecty = 1 if country==country[_n-1]
egen samecty = sum(_samecty), by(firmid year quartile)
drop _samecty
label var sec1_bem "Sector codes (BEM)"
label var sec1_aggbem "Sector codes (AGGBEM)"
label var numaffil "Count of affiliates"
label var sameaff "No. of same affiliates by region"
label var samecty "No. of same countries by region"

* FROM prep-translog-fdidata.do and prep-mvprobit-med-wagediff.do /* but retaining both years */
order firmid sec1_bem country year
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `quartile', nokeep
tab _m
drop _m
sort firmid year country
tempfile ptcntry
save `ptcntry'

* counts of same affil2id by mneid
preserve
  drop if year==`selyear'
  keep firmid year quartile sameaff samecty
  decode quartile, gen(_quartile)
  drop quartile
  rename _quartile quartile
  replace quartile = substr(quartile,1,2)
  replace quartile="Q9" if quartile==""
  bysort firmid year quartile: keep if _n==1
  rename firmid mneid
  reshape wide sameaff samecty, i(mneid year) j(quartile) string
  sort mneid year
  tempfile sameaffcty
  save `sameaffcty'
restore


* FROM prep-translog-fdidata.do /* but retaining both years */
rename firmid firm
tempfile hom
preserve
     keep firm year sec1_bem
     gen byte quartile = 0
     duplicates drop
     duplicates tag firm year, gen(_chk)
     count if _chk>=1
     if `r(N)' > 0 {
       disp as err "MNEs with contradictory home information"
       STOP
       }
     drop _chk
     compress
     sort firm year
     save `hom'
 restore
     keep firm year sec1_bem quartile country numaffil
     duplicates drop
     compress
     sort firm year
append using `hom'
label define quarts 0 "HOM", modify
label var quartile "Country group BEM"
qui do "$root/conc/secbem.do"
label values sec1_bem secbem
bysort firm quartile year: egen reg_numcntry=count(country)
bysort firm quartile year: egen reg_numaffil=sum(numaffil)
bysort firm quartile year: keep if _n==1
keep firm year sec1_bem quartile reg*
rename reg_numaffil naff
rename reg_numcntry ncty
keep firm year sec1_bem quartile naff ncty
fillin firm year quartile
bysort firm year: egen nobs=count(quartile)
tab nobs
count if nobs~=5 & nobs~=.
    if `r(N)' > 0 {
        disp as err "wrong number of observations"
        STOP
        }
drop nobs
rename firm mneid
bysort mneid year: egen _sec = mean(sec1_bem)
replace sec1_bem = _sec if sec1_bem==.
tab _sec
drop _sec
bysort mneid year: egen nreg=sum(_fillin)
replace nreg=5-nreg
tab nreg
count
drop if nreg==. /* do NOT drop MNEs that have only data for one region */
rename _fillin nofdi
rename quartile _quartile
decode _quartile, gen(quartile)
drop _quartile
compress
order mneid year quartile
sort mneid year quartile
order mneid year quartile nreg
label var nreg "No. of active regions"
label var naff "No. of affiliates by region"
label var ncty "No. of countries by region"
label var nofdi "Indic.: No FDI"
tempfile translog
save `translog'

* FROM prep-mvprobit-med-wagediff.do /* but working on both years */
use `ptcntry'
keep firmid year country quartile year sec1_bem
duplicates report firmid year country
count
collapse (max) sec1_bem, by(firmid year quartile)  /* firmid year's and id's one-to-one */
duplicates report firmid year quartile
count
fillin firmid year quartile
count
gen byte chosen=(_fillin~=1)
label var sec1_bem "Sector codes (BEM)"
drop _fillin
* reshape and label for mvprobit
foreach name in sec1_bem {
  forvalues i=`selyear'(${yrdiff})`tlogyear' {
    local lblyr = substr("`i'",-2,2)
    local lbl : variable label `name'
    gen `name'_`i'= `name'
    replace `name'_`i'=. if year~=`i'
    bysort firmid: egen _help = max(`name'_`i')
    replace `name'_`i'=_help if `name'_`i'==.
    label var `name'_`i' "`lbl' `lblyr'"
    drop _help
    local lbl_reshp_2 : variable label `name'
    }
  drop `name'
  }
duplicates report firmid year quartile
replace sec1_bem_`selyear'=sec1_bem_`tlogyear' if sec1_bem_`selyear'==. /* fill missing sectors */
replace sec1_bem_`tlogyear'=sec1_bem_`selyear' if sec1_bem_`tlogyear'==.
replace quartile=9 if quartile==.
gen region_year= quartile*100000+year
drop year quartile
reshape wide chosen, i(firmid) j(region_year)
local i=0
foreach name in $regqrt {
  local i=`i'+10
  forvalues j=`selyear'(${yrdiff})`tlogyear' {
    local lblyr = substr("`j'",-2,2)
    rename chosen`i'`j' chosen_`name'_`j'
    label var chosen_`name'_`j' "Presence `name' current year"
    }
  }
compress
rename firmid mneid
sort mneid
tempfile mvprobit
save `mvprobit'

* FROM translog-selct-2stp-cf.do /* but working on both years */
use `translog', clear
replace quartile=(substr(quartile,1,2))
replace quartile="Q9" if quartile==""
reshape wide naff ncty nofdi, i(mneid year nreg) j(quartile) string
sort mneid year
merge mneid using `mvprobit'
tab _merge
drop _merge
sort mneid year

*----------------------above code similar to #reg-pop-pattern-ger.do (except for minor modifications)------------------------------

* regional presence indicators and parent level regressors
foreach dyr in `selyear' `tlogyear' {
  local yr = substr("`dyr'",-2,2)
  if "`dyr'"=="`selyear'"   rename sec1_bem_`dyr' sec1_bem_${yrdiff}yrlg
  if "`dyr'"=="`selyear'"   label var sec1_bem_${yrdiff}yrlg "Sector codes (BEM) ${yrdiff} years ago"
  if "`dyr'"=="`tlogyear'"  rename sec1_bem_`dyr' sec1_bem_now
  if "`dyr'"=="`tlogyear'"  label var sec1_bem_now "Sector codes (BEM) current year"
  foreach reg in $regqrt {
    local r2dg = substr("`reg'",1,2)
    if "`dyr'"=="`selyear'"   rename chosen_`reg'_`dyr' i`r2dg'${yrdiff}yrlg
    if "`dyr'"=="`selyear'"   label var i`r2dg'${yrdiff}yrlg "Presence `reg' ${yrdiff} years ago"
    if "`dyr'"=="`tlogyear'"  rename chosen_`reg'_`dyr' i`r2dg'now
    if "`dyr'"=="`tlogyear'"  label var i`r2dg'now "Presence `reg' current year"
    }
  }
gen byte iHOnow = 1  /* Permanent presence in Home */
gen byte iHO${yrdiff}yrlg = 1  /* Permanent presence in Home */
label var iHOnow "Presence HOM current year"
label var iHO${yrdiff}yrlg "Presence HOM ${yrdiff} years ago"

keep if year == `tlogyear'
duplicates drop
sort mneid year
order mneid year nreg i*
save `pop`tlogyear''

} /* close `tlogyear' loop */

local i = 1
foreach tlogyear in 1998 1999 2000 2001  {
  if `i'==1  use `pop`tlogyear'', clear
  else       append using `pop`tlogyear''
  local i = `i' + 1
  }

fillin mneid year
tab year if _fillin
drop if _fillin
drop _fillin

tsset mneid year
sort mneid year
compress
save "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-quarts", replace

*----------------------above code identical to #reg-pop-pattern-ger.do------------------------------------------------------

log close
cd "$root"
