*! version 1.0.4  12apr2006  by Marc-Andreas Muendler muendler@ucsd.edu

/* Regional wages are supposed to be first (5) regressors in SUR equations */

translator set gph2eps logo off
translator set gph2ps  logo off
translator set gph2prn logo off

version 8
cd "$rootslct"
clear
set more off
set matsize 400
adopath + "$root/%stata/ado"

/* SIXTH DRAFT (v6) */

* FIRST COLUMN AND FIRST ROW OF ELASTICITY MATRICES (INTENSIVE AND EXTENSIVE) BY METHOD

foreach usemissg in $howmany {
foreach regr in $reglist {
  local ext "`regr'"
  if "`regr'" == "hm"  local ext ""
  foreach elstld in int ext tot {
  capture confirm file tex/v6`ext'/pt$par-af$aff-$waglvl-cf/`elstld'elast`usemissg'_tbl.dta
  if _rc == 0 {
    matload `elstld'elast`usemissg'_tbl, p(tex/v6`ext'/pt$par-af$aff-$waglvl-cf) over missing(.)
    * rename _se1 and _se4 rows with estimate name
    local rownames : rownames `elstld'elast`usemissg'_tbl
    local rownum : word count `rownames'
    tokenize `rownames'
    foreach reg in HOM $regagg {
      local r2dg = substr("`reg'",1,2)
      forvalues i = 1/`rownum' {
        local nextrow = `i' + 1
        local thenrow = `i' + 2
        if "``i''"=="rLDem`r2dg'" & "``nextrow''"=="_se1"  matname `elstld'elast`usemissg'_tbl rLDem`r2dg'_se1, rows(`nextrow') explicit
        if "``i''"=="rLDem`r2dg'" & "``nextrow''"=="_se4"  matname `elstld'elast`usemissg'_tbl rLDem`r2dg'_se4, rows(`nextrow') explicit
        if "``i''"=="rLDem`r2dg'" & "``thenrow''"=="_se4"  matname `elstld'elast`usemissg'_tbl rLDem`r2dg'_se4, rows(`thenrow') explicit
        }      
      }
    * extract first row and first column
    matorder `elstld'elast`usemissg'_tbl, m(`elstld'elast`usemissg'wHO`regr') ifc(mWageHO)
    matorder `elstld'elast`usemissg'wHO`regr', m(`elstld'elast`usemissg'wHO`regr') over ifr(rLDemHO rLDemHO_se4 rLDemCE rLDemCE_se4 rLDemDE rLDemDE_se4 rLDemOI rLDemOI_se4 rLDemWE rLDemWE_se4 e(theta_N))
    matrix coleq `elstld'elast`usemissg'wHO`regr' = wHO`usemissg'`regr'
    matorder `elstld'elast`usemissg'_tbl, m(`elstld'elast`usemissg'yHO`regr') ifr(rLDemHO rLDemHO_se4)
    tempname addobs
    mat `addobs' = `elstld'elast`usemissg'wHO`regr'[rownumb(`elstld'elast`usemissg'wHO`regr',"e(theta_N)"),colnumb(`elstld'elast`usemissg'wHO`regr',"mWageHO")] \ J(1,1,.)
    matname `addobs' e_theta_N, columns(1) explicit
    mat `elstld'elast`usemissg'yHO`regr' = `elstld'elast`usemissg'yHO`regr', `addobs'
    matrix roweq `elstld'elast`usemissg'yHO`regr' = yHO`usemissg'`regr'
    mat drop `elstld'elast`usemissg'_tbl
    }
    }
  }
} /* close `usemissg' loop */

foreach elstld in int ext tot {
  foreach usemissg in $howmany {
  foreach regr in $reglist {
    local ext "`regr'"
    if "`regr'" == "hm"  local ext ""
    capture local chk = rowsof(`elstld'elast`usemissg'wHO`regr') 
    if _rc == 0 {
      capture mat `elstld'elastwHO = `elstld'elastwHO , `elstld'elast`usemissg'wHO`regr'
      if _rc~=0  mat `elstld'elastwHO = `elstld'elast`usemissg'wHO`regr'
      mat drop `elstld'elast`usemissg'wHO`regr'
      capture mat `elstld'elastyHO = `elstld'elastyHO \ `elstld'elast`usemissg'yHO`regr'
      if _rc~=0  mat `elstld'elastyHO = `elstld'elast`usemissg'yHO`regr'
      mat drop `elstld'elast`usemissg'yHO`regr'
    }
    }
  }
} /* close `elstld' loop */

* output to tex
mat drop extelastyHO totelastyHO
foreach mat in totelastw extelastw intelastw intelasty  {
  local rownames : rowfullnames `mat'HO
  local rows : word count `rownames'
  tokenize `rownames'
  forvalues i = 1/`rows' {
    if subinstr("``i''","_se","",.)~="``i''"  matname `mat'HO _se, rows(`i') explicit
    }
  mat rename `mat'HO cmp`mat'_tbl
  * Load variable names and save for est2tex
  capture est2extlbl, addto(cmp`mat') retain p(tex/v6np/pt$par-af$aff-$waglvl-cf) replace
  if _rc~=0  est2extlbl, addto(cmp`mat') intex($rootdo/%stata/rowlbl-fdiselct) p(tex/v6np/pt$par-af$aff-$waglvl-cf) replace
  drop _all
  }
foreach mat in totelastw extelastw intelastw intelasty  {
  est2tex cmp`mat', replace dropall preserve mark(starse) path(tex/v6np/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99) ready
  }


* TRANSLOG REGRESSIONS

local howmany ""
if index("$howmany","1")~=0  local howmany 1  /* only usemissg 1 permitted */
foreach usemissg in `howmany' { /* begin `usemissg' loop */

* Load variable names and save for est2tex
est2extlbl, addto(translogcmp`usemissg') intex($rootdo/%stata/rowlbl-fdiselct) p(tex/v6np/pt$par-af$aff-$waglvl-cf) replace
clear

foreach regr in "hm" "np" {
  if "`regr'" == "hm"  local ext ""
  if "`regr'" == "np"  local ext "np"

    foreach type in b se e {
      tempname trlg`regr'`usemissg'`waglvl'_`type'
      * local trlg`regr'`usemissg'`waglvl'_`type' "trlg`regr'`usemissg'`waglvl'_`type'"
      drop _all
      matload translog`usemissg'_`type', p(estmat/v6`ext'/pt$par-af$aff-$waglvl-cf/translog`usemissg') over missing(.)
      if "`type'"~="e"  matins translog`usemissg'_`type', m(translog`usemissg'_`type') ifr(sWE:cf_wHO sWE:cf_wWE sWE:cf_wOI sWE:cf_wCE sWE:cf_wDE sWE:cf_tHO sWE:cf_tWE sWE:cf_tOI sWE:cf_tCE sWE:cf_tDE sWE:cf_kHO sWE:cf_kWE sWE:cf_kOI sWE:cf_kCE sWE:cf_kDE sWE:nofdiWE sWE:nofdiOI sWE:nofdiCE sWE:nofdiDE sWE:cfWE sWE:mWE sOI:cf_wHO sOI:cf_wWE sOI:cf_wOI sOI:cf_wCE sOI:cf_wDE sOI:cf_tHO sOI:cf_tWE sOI:cf_tOI sOI:cf_tCE sOI:cf_tDE sOI:cf_kHO sOI:cf_kWE sOI:cf_kOI sOI:cf_kCE sOI:cf_kDE sOI:nofdiWE sOI:nofdiOI sOI:nofdiCE sOI:nofdiDE sOI:cfOI sOI:mOI sCE:cf_wHO sCE:cf_wWE sCE:cf_wOI sCE:cf_wCE sCE:cf_wDE sCE:cf_tHO sCE:cf_tWE sCE:cf_tOI sCE:cf_tCE sCE:cf_tDE sCE:cf_kHO sCE:cf_kWE sCE:cf_kOI sCE:cf_kCE sCE:cf_kDE sCE:nofdiWE sCE:nofdiOI sCE:nofdiCE sCE:nofdiDE sCE:cfCE sCE:mCE sDE:cf_wHO sDE:cf_wWE sDE:cf_wOI sDE:cf_wCE sDE:cf_wDE sDE:cf_tHO sDE:cf_tWE sDE:cf_tOI sDE:cf_tCE sDE:cf_tDE sDE:cf_kHO sDE:cf_kWE sDE:cf_kOI sDE:cf_kCE sDE:cf_kDE sDE:nofdiWE sDE:nofdiOI sDE:nofdiCE sDE:nofdiDE sDE:cfDE sDE:mDE) over
      mat rename translog`usemissg'_`type' `trlg`regr'`usemissg'`waglvl'_`type''
      }
    local colmax = colsof(`trlg`regr'`usemissg'`waglvl'_e')
    local rowmax = rowsof(`trlg`regr'`usemissg'`waglvl'_e')
    tempname trlg`regr'`usemissg'`waglvl'_r
    * local trlg`regr'`usemissg'`waglvl'_r "trlg`regr'`usemissg'`waglvl'_r"
    mat `trlg`regr'`usemissg'`waglvl'_r' = `trlg`regr'`usemissg'`waglvl'_e'[1..6,1..`colmax']  /* Overall reports */
    mat `trlg`regr'`usemissg'`waglvl'_e' = `trlg`regr'`usemissg'`waglvl'_e'[7..`rowmax',1..`colmax']  /* Equation-specific reports */

    * Translog regression estimates
    local col = 1  /* First column from trlg`regr'`usemissg'`waglvl' output (only one exists) */
    foreach type in b se e {
        local rowmax = rowsof(`trlg`regr'`usemissg'`waglvl'_`type'')/4
        local colnames : roweq `trlg`regr'`usemissg'`waglvl'_`type''
        local colnames : list uniq colnames
        mat translog`regr'`usemissg'_`type' = `trlg`regr'`usemissg'`waglvl'_`type''[1..`rowmax',`col'] , `trlg`regr'`usemissg'`waglvl'_`type''[`rowmax'+1..`rowmax'*2,`col'] , `trlg`regr'`usemissg'`waglvl'_`type''[`rowmax'*2+1..`rowmax'*3,`col'] , `trlg`regr'`usemissg'`waglvl'_`type''[`rowmax'*3+1..`rowmax'*4,`col']
        local rownames : rownames translog`regr'`usemissg'_`type'
        tokenize `rownames'
        forvalues row = 1/`rowmax' {
            matname translog`regr'`usemissg'_`type' :``row'', rows(`row') explicit
            }
        if "`type'"~="e" {
            matname translog`regr'`usemissg'_`type' `colnames', columns(1..4) explicit
            }
        else {
            local colnames : colnames translog`regr'`usemissg'_b
            matname translog`regr'`usemissg'_`type' `colnames', columns(1..4) explicit
            matname translog`regr'`usemissg'_`type' e(r2) e(chi2) e(p), rows(1..3) explicit
            }
        }
    local rowmax = rowsof(`trlg`regr'`usemissg'`waglvl'_r')
    mat translog`regr'`usemissg'_r = `trlg`regr'`usemissg'`waglvl'_r'[1..`rowmax',`col'] , J(`rowmax',3,.)

} /* close `regr' loop */

foreach type in b se e r {
  mat translogcmp`usemissg'_`type' = transloghm`usemissg'_`type' , translognp`usemissg'_`type'
  mat drop transloghm`usemissg'_`type' translognp`usemissg'_`type'
  matrix coleq translogcmp`usemissg'_`type' = hkm hkm hkm hkm np np np np
  }
est2tex translogcmp`usemissg', replace dropall preserve mark(starse) path(tex/v6np/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99) extracols(4)
* est2tex trlgcmp`usemissg'`waglvl', replace dropall preserve mark(starse) path(tex/v6`ext'/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99)

} /* close `usemissg' loop */

cd "$root"
