*! version 1.3.7  14nov2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

* replace `maxiter' with $maxiter

drop _all
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-bstrap-pt$par-af$aff-$waglvl.log", replace

local reps = $reps
* ISUR with maximum number of iterations to avert non-convergence under bootstraps

#delimit ;

adopath + "$root/%stata/ado"; 


/* estimation routine */
/*--------------------*/
capture program drop sure2stp;
program define sure2stp;
  syntax [namelist], usemissg(integer);

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local namelist`r2dg' "";
    tokenize `namelist';
    local num :  word count `namelist';
    forvalues i = 1/`num' {;
      if substr("``i''",1,5)~="nofdi"  local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.);
      else                             local var = "``i''";
      local namelist`r2dg' "`namelist`r2dg'' `var'";
      };
    };

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    tempvar pxb;
    tempname chk;

    * probit regression without sector dummies;
    probit i`r2dg'00 iCE96 iDE96 iOI96 iWE96 i`r2dg'96_wHO ${paruse}, asis iterate($maxiter);

    * predict Mills ratios and delta from probit regression without sector dummies;
    tempname prb`r2dg' prb`r2dg'_r;
    mat `prb`r2dg'' = get(_b);
    mat `prb`r2dg'_r' = J(4,1,.);
    mat rownames `prb`r2dg''   = `r2dg'${usexvar};  /* estimates are in row vector */
    mat colnames `prb`r2dg'_r' = `r2dg'${usexvar};
    mat rownames `prb`r2dg'_r' = r(mean_iCE96) r(mean_iDE96) r(mean_iOI96) r(mean_iWE96);
    foreach loci in $regagg {;
      local li2dg = substr("`loci'",1,2);
      qui summ i`li2dg'96 if e(sample), meanonly;
      mat `prb`r2dg'_r'[rownumb(`prb`r2dg'_r',"r(mean_i`li2dg'96)"),1] = `r(mean)';
      };
    predict double `pxb', xb;
    gen double m`r2dg' = normd(`pxb') / normprob(`pxb');
    gen double dlta`r2dg' = m`r2dg' * (m`r2dg' + `pxb');  /* sigma_\nu = 1 in probit */
    qui summ dlta`r2dg' if e(sample) & i`r2dg'00, meanonly;
    scalar dltbar`r2dg' = r(mean);

    * predict log wage residual;
    foreach reg2 in HOM $regagg {;
      local r2dg2 = substr("`reg2'",1,2);
      reg lnw_`r2dg2' iCE96 iDE96 iOI96 iWE96 i`r2dg'96_wHO ${paruse};
      predict double cf`r2dg'_wres`r2dg2', res;
      replace cf`r2dg'_wres`r2dg2' = cf`r2dg' * cf`r2dg'_wres`r2dg2';
      replace cf`r2dg'_wres`r2dg2' = 0 if cf`r2dg'_wres`r2dg2'==.;
      };
    };
  gen byte dltaHO = .;  /* Permanent presence in Home */

  * build matrix prbdlnw of probit wage coefficients;
  foreach type in b se {;  /* Build up prbdlnw columns in order of $regagg, using wage coefficient */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      tempname plnw`r2dg';
      mat `plnw`r2dg'' = `prb`r2dg'' ';
      matkeep `plnw`r2dg'', matrix(`plnw`r2dg'') ifc(`r2dg'${usexvar}) over;
      matins `plnw`r2dg'', matrix(`plnw`r2dg'') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE96_wHO iDE96_wHO iOI96_wHO iWE96_wHO iCE96_wCE iDE96_wDE iOI96_wOI iWE96_wWE) over;
      };
    local cols : word count $regagg;
    tokenize $regagg;
    local j 1;
    local `j' = substr("``j''",1,2);
    mat prbdlnw_`type' = `plnw``j''';
    forvalues j = 2/`cols' {;
      local `j' = substr("``j''",1,2);
      mat prbdlnw_`type' = prbdlnw_`type' , `plnw``j''';
      };
    matrix colnames prbdlnw_`type' = $regagg;
    };
  foreach type in b se {;  /* Adjust prbdlnw entries by adding coefficient on interacted past presence indicator */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      mat prbdlnw_`type'[rownumb(prbdlnw_`type',"w_HOM"),colnumb(prbdlnw_`type',"`reg'")] = prbdlnw_`type'["w_HOM","`reg'"] + `prb`r2dg'_r'["r(mean_i`r2dg'96)","`r2dg'${usexvar}"] * prbdlnw_`type'["i`r2dg'96_wHO","`reg'"];
      foreach loci in $regagg {;
        local li2dg = substr("`loci'",1,2);
        mat prbdlnw_`type'[rownumb(prbdlnw_`type',"w_othr_`loci'"),colnumb(prbdlnw_`type',"`reg'")] = prbdlnw_`type'["w_othr_`loci'","`reg'"] + `prb`r2dg'_r'["r(mean_i`li2dg'96)","`r2dg'${usexvar}"] * prbdlnw_`type'["i`li2dg'96_w`li2dg'","`reg'"];
        };
      };
    * keep the five rows of wage effects only;
    local rows : word count HOM $regagg;
    mat prbdlnw_`type' = prbdlnw_`type'[1..`rows',1...];
    };
  * do not replace missing and insignificant with 0;
  * local regj = 0;
  * foreach reg in $regagg {;
  *   local regj = `regj' + 1;
  *   local wi = 0;
  *   foreach weff in HOM $regagg {;
  *     local wi = `wi' + 1;
  *     if prbdlnw_b[`wi',`regj'] == -999 | prbdlnw_b[`wi',`regj'] == . | prbdlnw_se[`wi',`regj'] == -999 | prbdlnw_se[`wi',`regj'] == . | abs(prbdlnw_b[`wi',`regj']/prbdlnw_se[`wi',`regj']) < abs(invnorm((100-${S_level})/200)) {;
  *       mat prbdlnw_b[`wi',`regj'] = 0;
  *       };
  *     };
  *   };
  mat prbdlnw = prbdlnw_b;
  mat drop prbdlnw_b prbdlnw_se;
  mat prbdlnw = prbdlnw '; /* regions in rows, wage effects in columns */
  local rownames : rowfullnames prbdlnw;
  local colnames : colfullnames prbdlnw;
  local rownum : word count `rownames';
  local colnum : word count `colnames';
  tokenize `rownames';
  forvalues rowi = 1/`rownum' {;
    local rownew = "i_" + substr("``rowi''",-3,3);
    matname prbdlnw `rownew', rows(`rowi') explicit;
    };
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "w_" + substr("``coli''",-3,3);
    matname prbdlnw `colnew', columns(`coli') explicit;
    };
  
  * second step: seemingly unrelated regressions;
  if `usemissg'~=2 {;
    sureg (sCE: yCE = `namelistCE' cfCE mCE, nocons)
          (sDE: yDE = `namelistDE' cfDE mDE, nocons)
          (sOI: yOI = `namelistOI' cfOI mOI, nocons)
          (sWE: yWE = `namelistWE' cfWE mWE, nocons)
          , constraints(2 3 4 6 7 9 12 13 14 15) isur iterate($maxiter);
      *   (sHO: yHO = `namelistHO' cfHO mHO, nocons); /* left-out equation */
    };

  local collbl "wHO wCE wDE wOI wWE";
  local rowlbl "sCE sDE sOI sWE";
  mat coefmat = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local eqlbl = substr("`lreg'",2,2);
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      if `usemissg'~=2  mat coefmat[`i',`j'] = _b[`lreg':cf`eqlbl'_`wreg'];
      };
    if `usemissg'~=2  mat coefmat[1,`i'] = _b[`lreg':cf`eqlbl'_wHO];
    };
  mat coefmat[1,1] = - (coefmat[2,1] + coefmat[3,1] + coefmat[4,1] + coefmat[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmat `collbl', columns(1..5) explicit;
  matname coefmat `rowlbl', rows(1..5) explicit;

  * Observation-specific extensive margins;
  foreach reg in HOM $regagg {;
    local r2dg = substr("`reg'",1,2);
    capture local mtrlg`r2dg' = _b[s`r2dg':m`r2dg'];  /* inverse of Mill's ratio penultimate regressor in re-run */
    if _rc {;
      local mtrlg`r2dg' = .;
      };
    foreach weff in HOM $regagg {;
      local w2dg = substr("`weff'",1,2);
      local g`r2dg'w`w2dg' = prbdlnw[rownumb(prbdlnw,"i_`reg'"),colnumb(prbdlnw,"w_`weff'")];
      local regvar = "w_othr_`weff'";
      if "`weff'"=="HOM"  local regvar = "w_`weff'";
      * qui gen double xmr`r2dg'w`w2dg' = `g`r2dg'w`w2dg'' * `mtrlg`r2dg'' * dlta`r2dg' * i`r2dg'00 / cf`r2dg' ; /* if log wages used */
      qui gen double xmr`r2dg'w`w2dg' = `g`r2dg'w`w2dg'' * `mtrlg`r2dg'' * dlta`r2dg' * i`r2dg'00 * `regvar' / cf`r2dg' ; /* if plain wages used */
      qui replace xmr`r2dg'w`w2dg' = 0 if xmr`r2dg'w`w2dg' == .;
      };
    };

  * Matrix of mean extensive margin correction terms;
  capture mat drop xmrmat;
  local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
  local colnames : colfullnames coefmat;
  local colnum : word count `colnames';
  foreach reg in `rownames' {;
    local r2dg = substr("`reg'",-2,2);
    tempname xmat`r2dg';
    mat `xmat`r2dg'' = J(1,`colnum',.);
    matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
    local colj = 0;
    foreach weff in `colnames' {;
      local colj = `colj' + 1;
      qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
      mat `xmat`r2dg''[1,`colj'] = r(mean);
      matname `xmat`r2dg'' `weff', columns(`colj') explicit;
      };
    capture mat xmrmat = xmrmat \ `xmat`r2dg'';
    if _rc {;
      mat xmrmat = `xmat`r2dg'';
      };
    };

  calcelast;
end;


/* elasticity posting */
/*--------------------*/
capture program drop calcelast;
program define calcelast, rclass;
  foreach reg in CE DE OI WE {;
    * qui predict double shat`reg', equation(s`reg') xb, if e(sample);
    qui gen double shat`reg' = s`reg';
    };
  qui gen double shatHO = sHO;
  collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
  mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector next */
  matname Tmat theta, rows(1) explicit;
  mat Tmat = Tmat';  /* Tmat transposed to a column vector */
  mat Tsqmat = Tmat * Tmat';

  * Calculate total cross-price elasticities (both margins);
  mat TotElast = coefmat + xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {; /* Fill diagonal entries */
      mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
    };
  * matname TotElast sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname TotElast wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list TotElast;
  * disp;

  * Calculate cross-price elasticities matrix at extensive margin;
  mat ExtElast = xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
      mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
      mat ExtElast[1,`r'] = 0;
    };
  * matname ExtElast sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname ExtElast wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list ExtElast;
  * disp;

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElast = coefmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
    };
  * matname IntElast sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname IntElast wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list IntElast;
  * disp;

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + colsof(`elsttyp'Elast);
    mat b`elsttyp'Elast = J(1,`cols',.);
    local i = 0;
    foreach regi in HO CE DE OI WE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO CE DE OI WE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'Elast) + `j';
        mat b`elsttyp'Elast[1,`col'] = `elsttyp'Elast[`i',`j'];
        matname b`elsttyp'Elast `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + `i';
      qui summ shat`regi', meanonly;
      mat b`elsttyp'Elast[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'Elast `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElast = bTotElast , bExtElast , bIntElast;

  local colnams : colfullnames bElast;
  tempname pseudocov;
  matrix `pseudocov' = -999*I(`cols'*3);
  matrix colnames `pseudocov' = `colnams';
  matrix rownames `pseudocov' = `colnams';

  ereturn post bElast `pseudocov';

end;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for probit estimation */
/*-------------------------------------*/

do $dp/!varsets.do;

/* data and main loop */
/*--------------------*/

local howmany = subinstr("$howmany","0","",.);  /* omnipresent MNE no permitted */
foreach usemissg in `howmany' {; /* begin `usemissg' loop */

capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf", clear;
drop mCE dltaCE mDE dltaDE mOI dltaOI mWE dltaWE;


/* Bootstrap SUR under restrictions */
/*----------------------------------*/

if `usemissg' == 0 {;
  local nofdi "";
  };
if `usemissg' == 1 {;
  local nofdi "nofdiCE nofdiDE nofdiOI nofdiWE";
  };

keep mneid sec1_bem iHO00 iCE00 iDE00 iOI00 iWE00 yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE iCE96* iDE96* iOI96* iWE96* ${paruse} cf??_wHO cf??_wCE cf??_wDE cf??_wOI cf??_wWE cf??_tHO cf??_tCE cf??_tDE cf??_tOI cf??_tWE cf??_kHO cf??_kCE cf??_kDE cf??_kOI cf??_kWE `nofdi' cfHO cfCE cfDE cfOI cfWE lnw_??;
* sure2stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE `nofdi', usemissg(`usemissg');

bootstrap "sure2stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE `nofdi', usemissg(`usemissg')" _b, 
        reps(`reps') double saving(estmat/v6/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap) every(50) dots replace;

mat drop coefmat xmrmat TotElast ExtElast IntElast bTotElast bExtElast bIntElast Tmat Tsqmat prbdlnw;

}; /* end of `usemissg' loop */

capture program drop sure2stp;
capture program drop calcelast;

log close;
cd "$root";
