*! version 1.3.3  19nov2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

/* Varcov correction assumes that selection equations have constant */
/* Selection equation assumed to have constant as last regressor */
/* Varcov correction assumes that sureg equations do not have constant (add a regressor called ones if constant needed) */
/* Sure equation assumed to have Mills ratio as last regressor */
/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/crossval-sureg-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.log", replace

local usemissg 1

*----------------------following code similar to translog-selct-2stp-cf-nonparam.do---------------------------------------------
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /v6npfs for /v6np, mneid year for mneid ---------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

mat drop _all

local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

local namelist "cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE"
  foreach reg in $regagg {
    local r2dg = substr("`reg'",1,2)
    local namelist`r2dg' ""
    tokenize `namelist'
    local num :  word count `namelist'
    forvalues i = 1/`num' {
      local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.)
      local namelist`r2dg' "`namelist`r2dg'' `var'"
      }
    }

adopath + "$root/%stata/ado"

#delimit ;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

* data section removed;

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

capture mkdir "$rootslct/tex/v6npfs";
capture mkdir "$rootslct/estmat/v6npfs";
capture mkdir "$rootslct/tex/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
drop ln_inter_now;
rename ln_inter_${yrdiff} ln_inter;

foreach var in turnover employmt fixdasst equity liab caplabrat profits profeqtyrat intmed wb exports {;
  replace `var'_par_${yrdiff}yrlg=0 if `var'_par_${yrdiff}yrlg==.;
  };

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do--------------------------------------------------;
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /n3npfs for /v6npr, mneid year for mneid --------------------------------------------------;
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --;


/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local dintact "ifdiCE ifdiDE ifdiWE ifdiOI";
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscores`r2dg' "psc`r2dg' psc`r2dg'_`r2dg' psc`r2dg'_`r2dg'_`r2dg'";
  tokenize `pscores`r2dg'';
  local num : word count `pscores`r2dg'';
  local remtrm "ifdi`r2dg'";
  local multact : list dintact - remtrm;
  foreach dummy in `multact' {;
    forvalues i = 1/`num' {;
      local addtrm "``i''*`dummy'";
      local pscores`r2dg' "`pscores`r2dg'' `addtrm'";
      };
    };
  };
* disp "`pscoresCE'"; * disp "`pscoresDE'"; * disp "`pscoresOI'"; * disp "`pscoresWE'";
local pscno : word count `pscoresCE';
disp "`pscno'";


*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

* note: data and matrix section removed;

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

* Create selection polynomial regressors;
tokenize $selser;
local selno : word count $selser;
forvalues i = 1/`selno' {;
  local varname "``i''";
  local preptrm = subinstr(subinstr("``i''","w_","",.),"_"," ",.);
  * first-order terms;
  local var1 :  word 1 of `preptrm';
  if lower("`var1'")~="`var1'"  local var1 "w_othr_`var1'";
  else  local var1 "ln_`var1'";
  if substr("`var1'",-3,3)=="HOM"  local var1 = subinstr("`var1'","_othr","",.);
  * second-order terms;
  local var2 :  word 2 of `preptrm';
  if lower("`var2'")~="`var2'" & length("`var2'")>0  local var2 "w_othr_`var2'";
  if lower("`var2'")=="`var2'" & length("`var2'")>0  local var2 "ln_`var2'";
  if length("`var2'")>0  local var2 " * `var2'";
  if substr("`var2'",-3,3)=="HOM"  local var2 = subinstr("`var2'","_othr","",.);
  * third-order terms;
  local var3 :  word 3 of `preptrm';
  if lower("`var3'")~="`var3'" & length("`var3'")>0  local var3 "w_othr_`var3'";
  if lower("`var3'")=="`var3'" & length("`var3'")>0  local var3 "ln_`var3'";
  if length("`var3'")>0  local var3 " * `var3'";
  if substr("`var3'",-3,3)=="HOM"  local var3 = subinstr("`var3'","_othr","",.);
  if length("`var2'")>0 {;
    qui gen double `varname' = `var1'`var2'`var3';
    label var `varname' "(`varname')";
    };
  };
  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };
      
*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

*----------------------following code specific to crossval-selct-2stp-cf-nonparam-allyrs.do-----------------------------------------;

* remove observations with missing regressors;
local remvar "${par_1} cf??_wHO cf??_wCE cf??_wDE cf??_wOI cf??_wWE cf??_tHO cf??_tCE cf??_tDE cf??_tOI cf??_tWE cf??_kHO cf??_kCE cf??_kDE cf??_kOI cf??_kWE nofdiDE nofdiOI nofdiWE cf??";
foreach var of varlist `remvar' {;
  drop if `var'==.;
  };

* number observations;
gen double obsid = _n;
label var obsid "Running observation number";
compress obsid;
local obstot = _N;

order mneid year;

/* first step: non-parametric selection estimation */
/*-------------------------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = ${usexvar}/${usexvar} {;
    local r2dg = substr("`reg'",1,2);
    tempname chk;
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * selection regressions without sector dummies (used for translog);
    * disp "parnp_`xvars': ${parnp_`xvars'}";
    regress i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${parnp_`xvars'};

    * predict propensity scores from selection regressions without sector dummies;
    if `xvars' == ${usexvar} {;   /* Only xvars ${usexvar} used for second stage */
      predict double psc`r2dg', xb;
      label var psc`r2dg' "Propensity score `r2dg' (xvars `xvars')";
      * summ psc`r2dg';
      };

    * predict log wage residual;
    foreach reg2 in HOM $regagg {;
      local r2dg2 = substr("`reg2'",1,2);
      reg lnw_`r2dg2' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${parnp_`xvars'};
      predict double cf`r2dg'_wres`r2dg2', res;
      replace cf`r2dg'_wres`r2dg2' = cf`r2dg' * cf`r2dg'_wres`r2dg2';
      replace cf`r2dg'_wres`r2dg2' = 0 if cf`r2dg'_wres`r2dg2'==.;
      };

    };  /* close xvars loop */
  };  /* close reg loop */

sort mneid year;

* Generate polynomial interaction terms for sureg regression;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  qui gen byte ifdi`r2dg' = 1 - nofdi`r2dg';
  qui gen double psc`r2dg'_`r2dg' = psc`r2dg'*psc`r2dg';
  qui gen double psc`r2dg'_`r2dg'_`r2dg' = psc`r2dg'_`r2dg'*psc`r2dg';
  };
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscser`r2dg';
  foreach var of local pscores`r2dg' {;
    local namvar = subinstr("`var'","*","_",.);
    capture qui gen double `namvar' = `var';
    local pscser`r2dg' "`pscser`r2dg'' `namvar'";
    };
  };
* disp "`pscserCE'"; * disp "`pscserDE'"; * disp "`pscserOI'"; * disp "`pscserWE'";
local pscno : word count `pscserCE';
disp "`pscno'";

/* second step: seemingly unrelated regressions with nonparam-allyrs error terms */
/*-------------------------------------------------------------------------------*/

forvalues poly = 1/3 {;

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    gen double yhat`r2dg'poly`poly'=.;
    * polynomial terms;
    if `poly'==3  local pscser`r2dg' = "psc`r2dg' psc`r2dg'_`r2dg' psc`r2dg'_`r2dg'_`r2dg'";
    if `poly'==2  local pscser`r2dg' = "psc`r2dg' psc`r2dg'_`r2dg'";
    if `poly'==1  local pscser`r2dg' = "psc`r2dg'";
    };
    
  forvalues num = 1/`obstot' {;
    qui sureg (sCE: yCE = `namelistCE' nofdiDE nofdiOI nofdiWE cfCE `pscserCE')
              (sDE: yDE = `namelistDE' nofdiCE nofdiOI nofdiWE cfDE `pscserDE')
              (sOI: yOI = `namelistOI' nofdiCE nofdiDE nofdiWE cfOI `pscserOI')
              (sWE: yWE = `namelistWE' nofdiCE nofdiDE nofdiOI cfWE `pscserWE')
              , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter),
              if obsid~=`num';
        *     (sHO: yHO = `namelistHO' nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscserHO'); /* left-out equation */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      qui predict double _yhat`r2dg'poly`poly', xb equation(s`r2dg');
      qui replace yhat`r2dg'poly`poly' = _yhat`r2dg'poly`poly' if obsid==`num';
      drop _yhat`r2dg'poly`poly';
      };
    };  /* close observations loop */

  };  /* close polynomial loop */


/* collapse sums of squared errors to table */
/*------------------------------------------*/

keep mneid year y?? yhat??poly?;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  forvalues poly = 1/3 {;
    gen double sqe`r2dg'poly`poly' = (y`r2dg' - yhat`r2dg'poly`poly')^2;
    };  /* close poly loop */
  };  /* close reg loop */
collapse (mean) sqe??poly?, fast;
gen byte _dummy = 1;
reshape long sqeCEpoly sqeDEpoly sqeOIpoly sqeWEpoly, i(_dummy) j(poly);
gen str6 _rowname = "poly_" + string(poly);
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  rename sqe`r2dg'poly sqe_`r2dg';
  };
drop _dummy poly;
save "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg/crossvalsure_tbl.dta", replace;
matload crossvalsure_tbl, p($rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg) over dropall;
est2tex crossvalsure, ready replace dropall preserve path($rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg) fancy;

log close;
cd "$root";
