*! version 1.1.2  30nov2008  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/qic-selct-2stp-$waglvl-pt$par-af$aff-cf-allyrs.log", replace

capture program drop qicm
program define qicm

  args corr r2dg interact xvars
  local corropt "`corr'"
  if "`corr'"=="sta2"  local corropt "sta 2"

  quietly {
    capture xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'}, family(binomial) link(probit) i(mneid) t(year) corr(`corropt') iterate(250)
    if _rc~=0  exit
    tempname T t
    mat `T' = e(V)
    mat `T' = Ai * `T'
    mat `t' = trace(`T')
    scalar off = `t'[1,1]
    tempvar q1 mu
    predict double `mu', mu
    gen double `q1' = i`r2dg'now * log(`mu'/(1-`mu')) + log(1-`mu')
    summ `q1', meanonly
    }
    
    mat qic`xvars'_tbl[rownumb(qic`xvars'_tbl,"`corr'"),colnumb(qic`xvars'_tbl,"`r2dg'")] = 2*(off - r(sum))
end

*----------------------following code similar to translog-selct-2stp-cf-nonparam.do---------------------------------------------
*-----alteration: keep first-stage and cross validate---------------------------------------------------------------------------
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /v6fs for /v6, mneid year for mneid ---------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

mat drop _all

local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

adopath + "$root/%stata/ado"

#delimit ;


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets.do;

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

forvalues xvars = $usexvar/`maxvars' {;
  mat qic`xvars'_tbl = J(6,4,.);
  matrix rownames qic`xvars'_tbl = ind exch ar1 ar2 unst sta2;
  matrix colnames qic`xvars'_tbl = CE DE OI WE;
  };

/* data */
/*------*/

local usemissg 1; /* no `usemissg' loop */

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

capture mkdir "$rootslct/tex/v6fs";
capture mkdir "$rootslct/estmat/v6fs";
capture mkdir "$rootslct/tex/v6fs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;


use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
tsset, clear;

foreach var in turnover employmt fixdasst equity liab caplabrat profits profeqtyrat intmed wb exports {;
  replace `var'_par_${yrdiff}yrlg=0 if `var'_par_${yrdiff}yrlg==.;
  };


/* first step: probit estimation */
/*-------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = $usexvar/`maxvars' {;
    local r2dg = substr("`reg'",1,2);
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * selection regressions without sector dummies (used for translog);
    * disp "polynomial terms: `polytrms'";
    xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'}, family(binomial) link(probit) i(mneid) t(year) corr(ind) iterate(250);
    mat Ai = e(V);
    mat Ai = syminv(Ai);

    foreach spec in ind exch ar1 ar2 unst sta2 {;
      qicm "`spec'" "`r2dg'" "`interact'" "`xvars'";
      };
      
    };  /* close xvars loop */
  };  /* close reg loop */


/* save matrix */
/*------------------------------------------*/

forvalues xvars = $usexvar/`maxvars' {;
  est2tex qic`xvars', ready replace dropall preserve path($rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf/byreg) fancy;
  };

log close;
cd "$root";
