*! version 1.0.1  22jun2005  by Marc Muendler muendler@ucsd.edu
*! version 1.0.3  21mar2006  by Marc Muendler muendler@ucsd.edu

cd "$rootslct"
clear
set mem 400m
set more off

capture mkdir "$rootslct/tex/desc"
capture mkdir "$rootslct/tex/desc/pt$par-af$aff"  /* Directories unaffected if they exist */

capture log close
log using "logs/tot-attrition-ger.log", replace


/* SAMPLE DESCRIPTIONS */

/* Complete FDI data */
use "$root/Xdata/affils-outwfdi96-01-eur-03mar2006", clear
keep if year==2000 | year==1996
keep firmid year country sec1
duplicates drop
codebook firmid year country sec1

/* Matched FDI-Ustan data, including observations with no parent information */
use "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006", clear
keep if year==2000 | year==1996
keep firmid year country sec1
duplicates drop
codebook firmid year country sec1

/* Data after Ustan-FDI match, dropping observations with no parent information */
* use "$root/Xmatch/affils-fdi-ustan-96-01-eur", clear
use "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006", clear
drop if ustan==.
keep if year==2000 | year==1996
keep firmid year country sec1 ustan
duplicates drop
codebook firmid year country sec1

/* Selection Paper data, removing 1996 Ustan duplicates */
use "$rootslct/Xdata/affils-fdi-ustan-96&00-plaineur", clear
keep if year==2000 | year==1996
keep firmid year country sec1
duplicates drop
codebook firmid year country sec1


/* ATTRITION PATTERNS IN POPULATION */
/*----------------------------------*/

foreach data in "Xdata/affils-outwfdi96-01-eur-03mar2006" "Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006" {

use "$root/`data'", clear
keep firmid year
duplicates drop
qui keep if year==1996 | year==2000
qui gen byte yr = 2 if year==2000
qui replace yr = 1 if year==1996
qui fillin firmid yr
gen indinsmpl = 1 - _fillin
drop _fillin
label define absence 1 "Presence" 0 "Absence"
label values indinsmpl absence
label var indinsmpl "Indic.: In sample"
tsset firmid yr
disp
disp "Transitions 1996 -> 2000: `data'"
xttrans indinsmpl, freq
qui count if yr==1
disp
disp "Year 1996 observation count: " `r(N)'
qui count if yr==2
disp
disp "Year 2000 observation count: " `r(N)'
codebook

}

foreach data in "Xustan/ustan-compl-03mar2006" {

use "$root/`data'", clear
keep ustan year
duplicates drop
qui keep if year==1996 | year==2000
qui gen byte yr = 2 if year==2000
qui replace yr = 1 if year==1996
qui fillin ustan yr
gen indinsmpl = 1 - _fillin
drop _fillin
label define absence 1 "Presence" 0 "Absence"
label values indinsmpl absence
label var indinsmpl "Indic.: In sample"
tsset ustan yr
disp
disp "Transitions 1996 -> 2000: `data'"
xttrans indinsmpl, freq
qui count if yr==1
disp
disp "Year 1996 observation count: " `r(N)'
qui count if yr==2
disp
disp "Year 2000 observation count: " `r(N)'
codebook

}


/* ATTRITION PATTERNS IN SAMPLE */
/*------------------------------*/

foreach data in "Xdata/affils-fdi-ustan-96&00-plaineur" {

use "$rootslct/`data'", clear
keep firmid year
duplicates drop
qui keep if year==1996 | year==2000
qui gen byte yr = 2 if year==2000
qui replace yr = 1 if year==1996
qui fillin firmid yr
gen indinsmpl = 1 - _fillin
drop _fillin
label define absence 1 "Presence" 0 "Absence"
label values indinsmpl absence
label var indinsmpl "Indic.: In sample"
tsset firmid yr
disp
disp "Transitions 1996 -> 2000: `data'"
xttrans indinsmpl, freq
qui count if yr==1
disp
disp "Year 1996 observation count: " `r(N)'
qui count if yr==2
disp
disp "Year 2000 observation count: " `r(N)'
codebook

}

log close
cd "$root"
