*! version 1.1.2  15sep2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 500m
set more off
capture log close

cd "$rootslct"
log using "logs/prep-competitors-exposure-pt$par-af$aff-allyrs.log", replace


/* Calculate Competitor Exposure Measures (employmt wb turnover fixdasst numaffil) */
/*---------------------------------------------------------------------------------*/

foreach year in 1996 1997 1998 1999 2000 2001 {

use firmid year sec1_bem employmt_??? wb_??? turnover_??? fixdasst_??? using "Xdata/data-parent-hostregion-pt$par-af$aff-allyrs" if year==`year', clear
drop year
foreach var in employmt wb turnover fixdasst {
  rename `var'_par `var'_HOM
  }
 
* firm-by-firm averages over all other MNEs
count
local totnum = `r(N)'
gen _no = _n
order _n
compress
preserve
  forvalues i = 0/`totnum' {
  tempfile cmpagg`i'
  restore, preserve
    * mean competitor variable by region and sector
    local sec1bem = sec1_bem[`i']
    qui drop if _no == `i'
    if `sec1bem'~=. { 
      qui keep if sec1_bem == `sec1bem'
      }
    collapse (mean) employmt_??? wb_??? turnover_??? fixdasst_???, fast
    gen _no = `i'
    order _no
    qui compress
    qui save `cmpagg`i''
    }
restore, preserve

tempfile competvar
qui use `cmpagg0', clear
forvalues i = 1/`totnum' {
  qui append using `cmpagg`i''
  }
sort _no
save `competvar'


/* Finalize */
/*----------*/

restore
keep _no firmid
sort _no
merge _no using `competvar'
tab _m
count if _m==1
if `r(N)' {
  disp as err "Incomplete observations for competitor variables"
  STOP
  }

drop _m _no

foreach reg in $reghomagg {
  label var employmt_`reg' "Employment `reg'"
  label var wb_`reg'       "Total wage bill `reg'"
  label var turnover_`reg' "Turnover [ppp] `reg'"
  label var fixdasst_`reg' "Fixed assets [quasi ppp] `reg'"
  foreach var in employmt wb turnover fixdasst {
    rename `var'_`reg' cmpt_`var'_`reg'
    }
  }

replace firmid = 0 if firmid==.
gen int year = `year'
label var year "Calendar Year"
order firmid year cmpt_employmt_??? cmpt_wb_??? cmpt_turnover_??? cmpt_fixdasst_???
compress
sort firmid year
save "Xdata/mneid-cafege-competitor-exposure-`year'-$waglvl-pt$par-af$aff", replace
}

log close
cd "$root"
