*! version 1.3.1  15jan2009  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.1  15jun2009  by Marc Muendler  muendler@ucsd.edu

/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-$waglvl-pt$par-af$aff-plainreg-cf.log", replace

mat drop _all

local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and mills ratio) */

local namelist "cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE"
  foreach reg in $regagg {
    local r2dg = substr("`reg'",1,2)
    local namelist`r2dg' ""
    tokenize `namelist'
    local num :  word count `namelist'
    forvalues i = 1/`num' {
      local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.)
      local namelist`r2dg' "`namelist`r2dg'' `var'"
      }
    }

adopath + "$root/%stata/ado"

#delimit ;

/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */

/* data */
/*------*/

local usemissg 1;  /* stack observations */

capture mkdir "$rootslct/tex/v6fs";
capture mkdir "$rootslct/estmat/v6fs";
capture mkdir "$rootslct/tex/v6fs/pt$par-af$aff-$waglvl-plainreg-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/byreg";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;

/* seemingly unrelated regressions */
/*---------------------------------*/

sureg (sCE: yCE = `namelistCE' nofdiCE nofdiDE nofdiOI nofdiWE cfCE, nocons)
      (sDE: yDE = `namelistDE' nofdiCE nofdiDE nofdiOI nofdiWE cfDE, nocons)
      (sOI: yOI = `namelistOI' nofdiCE nofdiDE nofdiOI nofdiWE cfOI, nocons)
      (sWE: yWE = `namelistWE' nofdiCE nofdiDE nofdiOI nofdiWE cfWE, nocons)
/*    , constraints(2 3 4 6 7 9 12 13 14 15) */
      , corr isur iterate($maxiter);
*     (sHO: yHO = `namelistHO' nofdiCE nofdiDE nofdiOI nofdiWE cfHO, nocons); /* left-out equation */

est2vec translog`usemissg', e(N rss k_eq levels chi2_bp df_bp r2_1 chi2_1 p_1 r2_2 chi2_2 p_2 r2_3 chi2_3 p_3 r2_4 chi2_4 p_4) name(translog_`usemissg');

order mneid year sHO kHO tHO wHO nofdiHO cfHO sCE kCE tCE wCE nofdiCE cfCE sDE kDE tDE wDE nofdiDE cfDE sOI kOI tOI wOI nofdiOI cfOI sWE kWE tWE wWE nofdiWE cfWE;


/* initial concavity checks */
/*--------------------------*/

* matrix to check (i) that the fitted cost shares sLOC_predicted are nonnegative;
mat negxhatcnt`usemissg' = J(2,4,.);
matname negxhatcnt`usemissg' r(N_neg_xhare) r(N), rows(1..2) explicit;
local i = 0;
foreach sreg in sCE sDE sOI sWE {;
  local i = `i' + 1;
  matname negxhatcnt`usemissg' `sreg', columns(`i') explicit;
  predict _`sreg' if e(sample), equation(`sreg') xb;
  qui count if _`sreg'<0 & e(sample);
  mat negxhatcnt`usemissg'[1,`i']=`r(N)';
  qui count if e(sample);
  mat negxhatcnt`usemissg'[2,`i']=`r(N)';
  };
drop _s*;


/* sample statistics for elasticities of substitution */
/*----------------------------------------------------*/

order mneid year nreg sec1_bem i*;
summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg') p(tex/v6fs/pt$par-af$aff-$waglvl-plainreg-cf) replace detail;
preserve;
  foreach var in sHO sCE sDE sOI sWE wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE cfHO cfCE cfDE cfOI cfWE {;
    replace `var' = . if `var'==0;
    };
  summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg'_missg) p(tex/v6fs/pt$par-af$aff-$waglvl-plainreg-cf) replace detail;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    summ2tex * if e(sample) & nofdi`r2dg'==0, c(mean sd N p50) name(summ_translog`usemissg'_missg`r2dg') p(tex/v6fs/pt$par-af$aff-$waglvl-plainreg-cf) replace detail;
    };
restore;
corr2tex sHO sCE sDE sOI sWE if e(sample), name(corrT_translog`usemissg') p(tex/v6fs/pt$par-af$aff-$waglvl-plainreg-cf) replace;


/* elasticities of substitution */
/*------------------------------*/

* Cross-wage coefficient matrix;
tempname VCE; /* resets prior `VCE' if defined */
tempname bcoef bse coefmat0 semat0 coefmat1 semat1 coefmat2 semat2 coefmat3 semat3 coefmat4 semat4; 
mat `bcoef' = e(b)';
mat `VCE' = e(V);
mat `bse' = vecdiag(`VCE')';
foreach mattyp in coef se {;
  mat ``mattyp'mat0' = J(5,1,.);
  local cnt 0;
  foreach reg in $regagg {;
    local cnt = `cnt' + 1;
    local r2dg = substr("`reg'",1,2);
    matorder `b`mattyp'', m(``mattyp'mat`cnt'') ifr(s`r2dg':cf`r2dg'_wHO s`r2dg':cf`r2dg'_wCE s`r2dg':cf`r2dg'_wDE s`r2dg':cf`r2dg'_wOI s`r2dg':cf`r2dg'_wWE);
    local col`cnt' : roweq ``mattyp'mat`cnt''; local col`cnt' = substr("`col`cnt''",1,3);
    };
  * mat list ``mattyp'mat1';
  * mat list ``mattyp'mat2';
  * mat list ``mattyp'mat3';
  * mat list ``mattyp'mat4';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  * mat list `mattyp'mat;
  mat ``mattyp'mat0' = `mattyp'mat[1,1..5] ';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  mat `mattyp'mat[1,1] = - (`mattyp'mat[2,1] + `mattyp'mat[3,1] + `mattyp'mat[4,1] + `mattyp'mat[5,1]);
  local collbl = subinstr("wHO `col1' `col2' `col3' `col4'","s","w",.);
  local rowlbl = "sHO `col1' `col2' `col3' `col4'";
  * disp "`collbl'";
  * disp "`rowlbl'";
  matname `mattyp'mat `collbl', columns(1..5) explicit;
  matname `mattyp'mat `rowlbl', rows(1..5) explicit;
};
* standard error for sHOwHO;
local sdHOHO = 0;
forvalues i = 2/5 {;
  forvalues j = 2/5 {;
    local sdHOHO = `sdHOHO' + semat[`i',`j'];
    };
  };
mat semat[1,1] = sqrt(`sdHOHO');
mat list coefmat; mat list semat;
tempname chk;
mat `chk' = vecdiag(coefmat); /* check for symmetry */
* if issym(coefmat)~=1 {; * disp as err "matrix coefmat not symmetric"; * STOP; * };

* Statistics for matrices of shares (predicted shares recommended by Berndt 1991 and Hayashi 2000 but not used);
local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
local eqs = subinstr("`rownames'","sHO","",.);
foreach reg in `eqs' {;
  local r2dg = substr("`reg'",-2,2);
  * qui predict double shat`r2dg', equation(s`r2dg') xb, if e(sample);
  gen double shat`r2dg' = s`r2dg';
  };
gen double shatHO = sHO;
preserve;
collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector below */
matname Tmat theta, rows(1) explicit;
restore, preserve;
collapse (sd) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_sd);
matname Tmat_sd theta_sd, rows(1) explicit;
restore, preserve;
collapse (count) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_N);
matname Tmat_N theta_N, rows(1) explicit;
restore, preserve;

* Zeta matrix (r2 in Anderson and Thursby 1986);
foreach sreg in HOM $regagg {;
  local sr2dg = substr("`sreg'",1,2);
  foreach wreg in HOM $regagg {;
    local wr2dg = substr("`wreg'",1,2);
    qui gen double r2s`sr2dg's`wr2dg' = Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]^(-3) * ( ( s`sr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")] ) * ( s`sr2dg'*s`wr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat[1,colnumb(Tmat,"s`wr2dg'")] - corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) + Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]*(Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")] - 1)*Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*( Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")] + corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) );
    };
  };
collapse (sum) r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE if e(sample), fast;
tempname zetatmp;
mkmat r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE, matrix(`zetatmp');
local shnames : colfullnames Tmat;
local shnames = subinstr("`shnames'","hat","",.);
mat zetamat = J(5,5,.);
matname zetamat `shnames', rows(1..5) explicit;
matname zetamat `shnames', columns(1..5) explicit;
foreach sr in `shnames' {;
  local sr2dg = subinstr("`sr'","s","",.);
  foreach wr in `shnames' {;
    local wr2dg = subinstr("`wr'","s","",.);
    mat zetamat[rownumb(zetamat,"`sr'"),colnumb(zetamat,"`wr'")] = `zetatmp'[1,colnumb(`zetatmp',"r2s`sr2dg's`wr2dg'")];
    };
  };
restore;

* Matrices of shares;
mat Tmat_all = Tmat \ Tmat_sd \ Tmat_N;
mat Tmat = Tmat'; /* Tmat transposed to a column vector */
mat Tsqmat = Tmat * Tmat';

* Calculate cross-price elasticities matrix at intensive margin;
mat IntElast = coefmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname IntElast `shnames', rows(1..5) explicit;
matname IntElast `shnames', columns(1..5) explicit;
mat list IntElast;
disp;

mat TotElast = IntElast;
mat ExtElast = J(5,5,.);
mat rowname ExtElast = `rownames';
mat colname ExtElast = `rownames';


/* additional concavity checks */
/*-----------------------------*/

* matrix to check (ii) that the cross price elasticities in TotElast sum to zero per row (not per column);
mat elastsum`usemissg' = J(2,5,0);
matname elastsum`usemissg' rowsum colsum, rows(1..2) explicit;
matname elastsum`usemissg' sHO sCE sDE sOI sWE, columns(1..5) explicit;
local i = 0;
foreach sreg in sHO sCE sDE sOI sWE {;
  local i = `i' + 1;
  forvalues j = 1/5 {;
    mat elastsum`usemissg'[1,`i'] = elastsum`usemissg'[1,`i'] + TotElast[`i',`j'];
    mat elastsum`usemissg'[2,`i'] = elastsum`usemissg'[2,`i'] + TotElast[`j',`i'];
    };
  };

* matrix to check (iii) that the AUmat matrices of Allen-Uzawa substitution elasticities are negative semi-definite at each observation;
* calculate MNE-level elasticities (in-sample predictions); 
* set elasticities to zero for regions with no FDI-presence;
local i = 0;
foreach reg1 in HO CE DE OI WE {;
  local i = `i' + 1;
  local j = 0;
  foreach reg2 in HO CE DE OI WE {;
    local j = `j' + 1;
    local coeff = coefmat[`i',`j'];
    if `i' ~= `j' {; 
      qui gen double sigma`reg1's`reg2' = (`coeff' + s`reg1' * s`reg2') / (s`reg1' * s`reg2') if e(sample);
      };
    if `i' == `j' {; 
      qui gen double sigma`reg1's`reg1' = (`coeff' + (s`reg1')^2 - s`reg1') / (s`reg1')^2 if e(sample);
      };      
    qui replace sigma`reg1's`reg2'=0 if sigma`reg1's`reg2'==.;
    label var sigma`reg1's`reg2' "AU elast. empl`reg1' empl`reg2'";
    };
  };
qui count;
local obsnum = `r(N)';
tempname AUmatobs eigenvec eigenval;
mat negeivalcnt`usemissg' = J(1,5,0) \ J(1,5,`obsnum');
matname negeivalcnt`usemissg' r(N_wklyneg_eigval) r(N), rows(1..2) explicit;
matname negeivalcnt`usemissg' wklyneg_1 wklyneg_2 wklyneg_3 wklyneg_4 wklyneg_5, columns(1..5) explicit;
forvalues obs = 1/`obsnum'{;
  mat `AUmatobs' = J(5,5,.);
  local i = 0;
  foreach reg1 in HO CE DE OI WE {;
    local i = `i' + 1;
    local j = 0;
    foreach reg2 in HO CE DE OI WE {;
      local j = `j' + 1;
      mat `AUmatobs'[`i',`j'] = sigma`reg1's`reg2'[`obs'];
      };
    };
  capture matrix symeigen `eigenvec' `eigenval' = `AUmatobs';
  if _rc == 0 {;
    matname `eigenval' `eigenval'ue, rows(1) explicit;
    mat drop `eigenvec';
    local cntwklyneg = 0;
    forvalues k = 1/5 {;
      if `eigenval'[1,`k'] <= 1.0e-06 {;  /* machine-size weakly negative */
        local cntwklyneg = `cntwklyneg' + 1;
        };
      };
    mat negeivalcnt`usemissg'[1,`cntwklyneg'] = negeivalcnt`usemissg'[1,`cntwklyneg']+1;
    };
  };


/* matrix output */
/*---------------*/

foreach type in b se e {;
    drop _all;
    matsave translog`usemissg'_`type', p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') t(double) replace;
    };
matsave negxhatcnt`usemissg', p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace; 
matsave elastsum`usemissg', p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace; 
matsave negeivalcnt`usemissg', p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace; 

mat intelast`usemissg'_b = IntElast;
matsave intelast`usemissg'_b, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;
mat extelast`usemissg'_b = ExtElast;
matsave extelast`usemissg'_b, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;
mat totelast`usemissg'_b = TotElast;
matsave totelast`usemissg'_b, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;

mat vce`usemissg'_tbl = `VCE';
local cols = colsof(vce`usemissg'_tbl);
matsave vce`usemissg'_tbl, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;

mat tmat`usemissg'_tbl = Tmat_all;
matsave tmat`usemissg'_tbl, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;
mat zetamat`usemissg'_tbl = zetamat;
matsave zetamat`usemissg'_tbl, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;

mat coefmat`usemissg'_tbl = coefmat;
matname coefmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname coefmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave coefmat`usemissg'_tbl, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;

mat semat`usemissg'_tbl = semat;
matname semat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname semat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave semat`usemissg'_tbl, p(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg') dropall t(double) replace;

* clean up;
drop _all;
mat drop coefmat semat zetamat Tmat Tmat_sd Tmat_N Tmat_all Tsqmat TotElast ExtElast IntElast;
foreach mat in summ_translog`usemissg' summ_translog`usemissg'_missg corrT_translog`usemissg' vce`usemissg' coefmat`usemissg' semat`usemissg' tmat`usemissg' zetamat`usemissg' {;
  mat drop `mat'_tbl;
  };
foreach type in b se e r {;
  capture mat drop translog`usemissg'_`type';
  };
mat drop negxhatcnt`usemissg' elastsum`usemissg' negeivalcnt`usemissg';
mat drop totelast`usemissg'_b;
mat drop intelast`usemissg'_b;
mat drop extelast`usemissg'_b;


log close;
cd "$root";
