*! version 1.4.1  09jun2009  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  17jul2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-uncorr-selct2stp-bstrap-pt$par-af$aff-$waglvl-allyrs.log", replace

local reps = $reps
* ISUR with maximum number of iterations to avert non-convergence under bootstraps

local usemissg 1

#delimit ;

adopath + "$root/%stata/ado"; 


/* estimation master routine */
/*---------------------------*/
capture program drop sureboth;
program define sureboth;
  syntax [namelist], usemissg(integer);
  local notUnc "cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE";
  local nameUnc : list namelist - notUnc;
  sureUnc `nameUnc';
  sure2stp `namelist', usemissg(`usemissg');
  postreldif;
end;

capture program drop postreldif;
program define postreldif, rclass;
  mat bElastRlDf = bElastUnc;
  mat bElastRlDf = bElastRlDf - bElast2st;
  local rows = rowsof(bElastRlDf);
  local cols = colsof(bElastRlDf);
  forvalues i = 1/`rows' {;
    forvalues j = 1/`cols' {;
      mat bElastRlDf[`i',`j'] = bElastRlDf[`i',`j'] / bElast2st[`i',`j'];
      if bElastRlDf[`i',`j']==.  mat bElastRlDf[`i',`j']=0;
      };
    };
  local colnams : colfullnames bElastRlDf;
  tempname pseudocov;
  matrix `pseudocov' = -999*I(`cols');
  matrix colnames `pseudocov' = `colnams';
  matrix rownames `pseudocov' = `colnams';
  ereturn post bElastRlDf `pseudocov';
end;


/* sureUnc estimation routine */
/*----------------------------*/
capture program drop sureUnc;
program define sureUnc;
  syntax [namelist];

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local namelist`r2dg' "";
    tokenize `namelist';
    local num :  word count `namelist';
    forvalues i = 1/`num' {;
      if substr("``i''",1,5)~="nofdi"  local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.);
      else                             local var = "``i''";
      local namelist`r2dg' "`namelist`r2dg'' `var'";
      };
    };

  * one step: seemingly unrelated regressions;
  sureg (sCE: yCE = `namelistCE' cfCE, nocons)
        (sDE: yDE = `namelistDE' cfDE, nocons)
        (sOI: yOI = `namelistOI' cfOI, nocons)
        (sWE: yWE = `namelistWE' cfWE, nocons)
        if year>=1998
        , constraints(2 3 4 6 7 9 12 13 14 15) isur iterate($maxiter);
    *   (sHO: yHO = `namelistHO' cfHO, nocons); /* left-out equation */

  local collbl "wHO wCE wDE wOI wWE";
  local rowlbl "sCE sDE sOI sWE";
  mat coefmatUnc = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local eqlbl = substr("`lreg'",2,2);
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      mat coefmatUnc[`i',`j'] = _b[`lreg':cf`eqlbl'_`wreg'];
      };
    mat coefmatUnc[1,`i'] = _b[`lreg':cf`eqlbl'_wHO];
    };
  mat coefmatUnc[1,1] = - (coefmatUnc[2,1] + coefmatUnc[3,1] + coefmatUnc[4,1] + coefmatUnc[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmatUnc `collbl', columns(1..5) explicit;
  matname coefmatUnc `rowlbl', rows(1..5) explicit;

  calcelastUnc;
end;

/* sureUnc elasticity */
/*--------------------*/
capture program drop calcelastUnc;
program define calcelastUnc, rclass;
  tempfile tmp;
  foreach reg in CE DE OI WE {;
    * qui predict double sunc`reg', equation(s`reg') xb, if e(sample);
    qui gen double sunc`reg' = s`reg';
    };
  qui gen double suncHO = sHO;
  save `tmp';
  collapse (mean) suncHO suncCE suncDE suncOI suncWE if e(sample), fast;
  mkmat suncHO suncCE suncDE suncOI suncWE, matrix(TmatUnc);  /* TmatUnc to be transposed to a column vector next */
  use `tmp', clear;
  matname TmatUnc theta, rows(1) explicit;
  mat TmatUnc = TmatUnc';  /* TmatUnc transposed to a column vector */
  mat TsqmatUnc = TmatUnc * TmatUnc';

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElastUnc = coefmatUnc + TsqmatUnc;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElastUnc[`r',`m'] = IntElastUnc[`r',`m'] / TmatUnc[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElastUnc[`r',`m'] = IntElastUnc[`r',`m'] / TmatUnc[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElastUnc[`r',`r'] = IntElastUnc[`r',`r'] / TmatUnc[`r',1] - 1;
    };
  * matname IntElastUnc sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname IntElastUnc wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list IntElastUnc;
  * disp;

  mat TotElastUnc = IntElastUnc;
  mat ExtElastUnc = J(5,5,-999);
  mat rowname ExtElastUnc = `rownames';
  mat colname ExtElastUnc = `rownames';

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'ElastUnc) * colsof(`elsttyp'ElastUnc) + colsof(`elsttyp'ElastUnc);
    mat b`elsttyp'ElastUnc = J(1,`cols',.);
    local i = 0;
    foreach regi in HO CE DE OI WE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO CE DE OI WE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'ElastUnc) + `j';
        mat b`elsttyp'ElastUnc[1,`col'] = `elsttyp'ElastUnc[`i',`j'];
        matname b`elsttyp'ElastUnc `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'ElastUnc) * colsof(`elsttyp'ElastUnc) + `i';
      qui summ sunc`regi', meanonly;
      mat b`elsttyp'ElastUnc[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'ElastUnc `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElastUnc = bTotElastUnc , bExtElastUnc , bIntElastUnc;
end;

/* sure2stp estimation routine */
/*-----------------------------*/
capture program drop sure2stp;
program define sure2stp;
  syntax [namelist], usemissg(integer);

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local namelist`r2dg' "";
    tokenize `namelist';
    local num :  word count `namelist';
    forvalues i = 1/`num' {;
      if substr("``i''",1,5)~="nofdi"  local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.);
      else                             local var = "``i''";
      local namelist`r2dg' "`namelist`r2dg'' `var'";
      };
    };

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    tempvar pxb;
    tempname chk;

    * probit regression without sector dummies;
    probit i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO ${paruse}, asis iterate($maxiter);

    * predict Mills ratios and delta from probit regression without sector dummies;
    tempname prb`r2dg' prb`r2dg'_r;
    mat `prb`r2dg'' = get(_b);
    mat `prb`r2dg'_r' = J(4,1,.);
    mat rownames `prb`r2dg''   = `r2dg'${usexvar};  /* estimates are in row vector */
    mat colnames `prb`r2dg'_r' = `r2dg'${usexvar};
    mat rownames `prb`r2dg'_r' = r(mean_iCE${yrdiff}yrlg) r(mean_iDE${yrdiff}yrlg) r(mean_iOI${yrdiff}yrlg) r(mean_iWE${yrdiff}yrlg);
    foreach loci in $regagg {;
      local li2dg = substr("`loci'",1,2);
      qui summ i`li2dg'${yrdiff}yrlg if e(sample), meanonly;
      mat `prb`r2dg'_r'[rownumb(`prb`r2dg'_r',"r(mean_i`li2dg'${yrdiff}yrlg)"),1] = `r(mean)';
      };
    predict double `pxb', xb;
    gen double m`r2dg' = normd(`pxb') / normprob(`pxb');
    gen double dlta`r2dg' = m`r2dg' * (m`r2dg' + `pxb');  /* sigma_\nu = 1 in probit */
    qui summ dlta`r2dg' if e(sample) & i`r2dg'now, meanonly;
    scalar dltbar`r2dg' = r(mean);

    * predict log wage residual;
    foreach reg2 in HOM $regagg {;
      local r2dg2 = substr("`reg2'",1,2);
      reg lnw_`r2dg2' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO ${paruse};
      predict double cf`r2dg'_wres`r2dg2', res;
      replace cf`r2dg'_wres`r2dg2' = cf`r2dg' * cf`r2dg'_wres`r2dg2';
      replace cf`r2dg'_wres`r2dg2' = 0 if cf`r2dg'_wres`r2dg2'==.;
      };
    };
  gen byte dltaHO = .;  /* Permanent presence in Home */

  * build matrix prbdlnw of probit wage coefficients;
  foreach type in b se {;  /* Build up prbdlnw columns in order of $regagg, using wage coefficient */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      tempname plnw`r2dg';
      mat `plnw`r2dg'' = `prb`r2dg'' ';
      matkeep `plnw`r2dg'', matrix(`plnw`r2dg'') ifc(`r2dg'${usexvar}) over;
      matins `plnw`r2dg'', matrix(`plnw`r2dg'') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE${yrdiff}yrlg_wHO iDE${yrdiff}yrlg_wHO iOI${yrdiff}yrlg_wHO iWE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wWE) over;
      };
    local cols : word count $regagg;
    tokenize $regagg;
    local j 1;
    local `j' = substr("``j''",1,2);
    mat prbdlnw_`type' = `plnw``j''';
    forvalues j = 2/`cols' {;
      local `j' = substr("``j''",1,2);
      mat prbdlnw_`type' = prbdlnw_`type' , `plnw``j''';
      };
    matrix colnames prbdlnw_`type' = $regagg;
    };
  foreach type in b se {;  /* Adjust prbdlnw entries by adding coefficient on interacted past presence indicator */
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      mat prbdlnw_`type'[rownumb(prbdlnw_`type',"w_HOM"),colnumb(prbdlnw_`type',"`reg'")] = prbdlnw_`type'["w_HOM","`reg'"] + `prb`r2dg'_r'["r(mean_i`r2dg'${yrdiff}yrlg)","`r2dg'${usexvar}"] * prbdlnw_`type'["i`r2dg'${yrdiff}yrlg_wHO","`reg'"];
      foreach loci in $regagg {;
        local li2dg = substr("`loci'",1,2);
        mat prbdlnw_`type'[rownumb(prbdlnw_`type',"w_othr_`loci'"),colnumb(prbdlnw_`type',"`reg'")] = prbdlnw_`type'["w_othr_`loci'","`reg'"] + `prb`r2dg'_r'["r(mean_i`li2dg'${yrdiff}yrlg)","`r2dg'${usexvar}"] * prbdlnw_`type'["i`li2dg'${yrdiff}yrlg_w`li2dg'","`reg'"];
        };
      };
    * keep the five rows of wage effects only;
    local rows : word count HOM $regagg;
    mat prbdlnw_`type' = prbdlnw_`type'[1..`rows',1...];
    };
  * do not replace missing and insignificant with 0;
  * local regj = 0;
  * foreach reg in $regagg {;
  *   local regj = `regj' + 1;
  *   local wi = 0;
  *   foreach weff in HOM $regagg {;
  *     local wi = `wi' + 1;
  *     if prbdlnw_b[`wi',`regj'] == -999 | prbdlnw_b[`wi',`regj'] == . | prbdlnw_se[`wi',`regj'] == -999 | prbdlnw_se[`wi',`regj'] == . | abs(prbdlnw_b[`wi',`regj']/prbdlnw_se[`wi',`regj']) < abs(invnorm((100-${S_level})/200)) {;
  *       mat prbdlnw_b[`wi',`regj'] = 0;
  *       };
  *     };
  *   };
  mat prbdlnw = prbdlnw_b;
  mat drop prbdlnw_b prbdlnw_se;
  mat prbdlnw = prbdlnw '; /* regions in rows, wage effects in columns */
  local rownames : rowfullnames prbdlnw;
  local colnames : colfullnames prbdlnw;
  local rownum : word count `rownames';
  local colnum : word count `colnames';
  tokenize `rownames';
  forvalues rowi = 1/`rownum' {;
    local rownew = "i_" + substr("``rowi''",-3,3);
    matname prbdlnw `rownew', rows(`rowi') explicit;
    };
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "w_" + substr("``coli''",-3,3);
    matname prbdlnw `colnew', columns(`coli') explicit;
    };
  
  * second step: seemingly unrelated regressions;
  if `usemissg'~=2 {;
    sureg (sCE: yCE = `namelistCE' cfCE mCE, nocons)
          (sDE: yDE = `namelistDE' cfDE mDE, nocons)
          (sOI: yOI = `namelistOI' cfOI mOI, nocons)
          (sWE: yWE = `namelistWE' cfWE mWE, nocons)
          , constraints(2 3 4 6 7 9 12 13 14 15) isur iterate($maxiter);
      *   (sHO: yHO = `namelistHO' cfHO mHO, nocons); /* left-out equation */
    };
  local collbl "wHO wCE wDE wOI wWE";
  local rowlbl "sCE sDE sOI sWE";
  mat coefmat2st = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local eqlbl = substr("`lreg'",2,2);
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      if `usemissg'~=2  mat coefmat2st[`i',`j'] = _b[`lreg':cf`eqlbl'_`wreg'];
      };
    if `usemissg'~=2  mat coefmat2st[1,`i'] = _b[`lreg':cf`eqlbl'_wHO];
    };
  mat coefmat2st[1,1] = - (coefmat2st[2,1] + coefmat2st[3,1] + coefmat2st[4,1] + coefmat2st[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmat2st `collbl', columns(1..5) explicit;
  matname coefmat2st `rowlbl', rows(1..5) explicit;

  * Observation-specific extensive margins;
  foreach reg in HOM $regagg {;
    local r2dg = substr("`reg'",1,2);
    capture local mtrlg`r2dg' = _b[s`r2dg':m`r2dg'];  /* inverse of Mill's ratio penultimate regressor in re-run */
    if _rc {;
      local mtrlg`r2dg' = .;
      };
    foreach weff in HOM $regagg {;
      local w2dg = substr("`weff'",1,2);
      local g`r2dg'w`w2dg' = prbdlnw[rownumb(prbdlnw,"i_`reg'"),colnumb(prbdlnw,"w_`weff'")];
      local regvar = "w_othr_`weff'";
      if "`weff'"=="HOM"  local regvar = "w_`weff'";
      * qui gen double xmr`r2dg'w`w2dg' = `g`r2dg'w`w2dg'' * `mtrlg`r2dg'' * dlta`r2dg' * i`r2dg'now / cf`r2dg' ; /* if log wages used */
      qui gen double xmr`r2dg'w`w2dg' = `g`r2dg'w`w2dg'' * `mtrlg`r2dg'' * dlta`r2dg' * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used */
      qui replace xmr`r2dg'w`w2dg' = 0 if xmr`r2dg'w`w2dg' == .;
      };
    };

  * Matrix of mean extensive margin correction terms;
  capture mat drop xmrmat;
  local rownames : rowfullnames coefmat2st;  /* Match regional pattern in coefmat2st at intensive margin */
  local colnames : colfullnames coefmat2st;
  local colnum : word count `colnames';
  foreach reg in `rownames' {;
    local r2dg = substr("`reg'",-2,2);
    tempname xmat`r2dg';
    mat `xmat`r2dg'' = J(1,`colnum',.);
    matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
    local colj = 0;
    foreach weff in `colnames' {;
      local colj = `colj' + 1;
      qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
      mat `xmat`r2dg''[1,`colj'] = r(mean);
      matname `xmat`r2dg'' `weff', columns(`colj') explicit;
      };
    capture mat xmrmat = xmrmat \ `xmat`r2dg'';
    if _rc {;
      mat xmrmat = `xmat`r2dg'';
      };
    };

  calcelast2st;
end;

/* sure2stp elasticity */
/*---------------------*/
capture program drop calcelast2st;
program define calcelast2st, rclass;
  tempfile tmp;
  foreach reg in CE DE OI WE {;
    * qui predict double s2st`reg', equation(s`reg') xb, if e(sample);
    qui gen double s2st`reg' = s`reg';
    };
  qui gen double s2stHO = sHO;
  save `tmp';
  collapse (mean) s2stHO s2stCE s2stDE s2stOI s2stWE if e(sample), fast;
  mkmat s2stHO s2stCE s2stDE s2stOI s2stWE, matrix(Tmat2st);  /* Tmat2st to be transposed to a column vector next */
  use `tmp', clear;
  matname Tmat2st theta, rows(1) explicit;
  mat Tmat2st = Tmat2st';  /* Tmat2st transposed to a column vector */
  mat Tsqmat2st = Tmat2st * Tmat2st';

  * Calculate total cross-price elasticities (both margins);
  mat TotElast2st = coefmat2st + xmrmat + Tsqmat2st;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat TotElast2st[`r',`m'] = TotElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat TotElast2st[`r',`m'] = TotElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues r = 1/5 {; /* Fill diagonal entries */
      mat TotElast2st[`r',`r'] = TotElast2st[`r',`r'] / Tmat2st[`r',1] - 1;
    };
  * matname TotElast2st sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname TotElast2st wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list TotElast2st;
  * disp;

  * Calculate cross-price elasticities matrix at extensive margin;
  mat ExtElast2st = xmrmat + Tsqmat2st;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat ExtElast2st[`r',`m'] = ExtElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat ExtElast2st[`r',`m'] = ExtElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
      mat ExtElast2st[`r',`r'] = ExtElast2st[`r',`r'] / Tmat2st[`r',1] - 1;
      mat ExtElast2st[1,`r'] = 0;
    };
  * matname ExtElast2st sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname ExtElast2st wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list ExtElast2st;
  * disp;

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElast2st = coefmat2st + Tsqmat2st;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElast2st[`r',`m'] = IntElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElast2st[`r',`m'] = IntElast2st[`r',`m'] / Tmat2st[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElast2st[`r',`r'] = IntElast2st[`r',`r'] / Tmat2st[`r',1] - 1;
    };
  * matname IntElast2st sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname IntElast2st wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list IntElast2st;
  * disp;

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'Elast2st) * colsof(`elsttyp'Elast2st) + colsof(`elsttyp'Elast2st);
    mat b`elsttyp'Elast2st = J(1,`cols',.);
    local i = 0;
    foreach regi in HO CE DE OI WE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO CE DE OI WE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'Elast2st) + `j';
        mat b`elsttyp'Elast2st[1,`col'] = `elsttyp'Elast2st[`i',`j'];
        matname b`elsttyp'Elast2st `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'Elast2st) * colsof(`elsttyp'Elast2st) + `i';
      qui summ s2st`regi', meanonly;
      mat b`elsttyp'Elast2st[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'Elast2st `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElast2st = bTotElast2st , bExtElast2st , bIntElast2st;
end;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for probit estimation */
/*-------------------------------------*/

do $dpfsref/!varsets.do;


/* data and main loop */
/*--------------------*/

capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-uncorr-selct2stp-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-uncorr-selct2stp-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs", clear;
drop mCE dltaCE mDE dltaDE mOI dltaOI mWE dltaWE;


/* Bootstrap SUR under restrictions */
/*----------------------------------*/

if `usemissg' == 0 {;
  local nofdi "";
  };
if `usemissg' == 1 {;
  local nofdi "nofdiCE nofdiDE nofdiOI nofdiWE";
  };

keep mneid year sec1_bem iHOnow iCEnow iDEnow iOInow iWEnow yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE iCE${yrdiff}yrlg* iDE${yrdiff}yrlg* iOI${yrdiff}yrlg* iWE${yrdiff}yrlg* ${paruse} cf??_wHO cf??_wCE cf??_wDE cf??_wOI cf??_wWE cf??_tHO cf??_tCE cf??_tDE cf??_tOI cf??_tWE cf??_kHO cf??_kCE cf??_kDE cf??_kOI cf??_kWE `nofdi' cfHO cfCE cfDE cfOI cfWE lnw_??;
* sureUnc cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE `nofdi';
* sure2stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE `nofdi', usemissg(`usemissg');
* sureboth cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE `nofdi', usemissg(`usemissg');
* mat bElastRlDf = e(b);
* mat list bElastRlDf;

bootstrap "sureboth cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE `nofdi', usemissg(`usemissg')" _b, 
        reps(`reps') double saving(estmat/v6fs/pt$par-af$aff-$waglvl-uncorr-selct2stp-cf/translog`usemissg'/elast`usemissg'_bstrap) every(50) dots replace;

mat drop coefmatUnc TotElastUnc ExtElastUnc IntElastUnc bTotElastUnc bExtElastUnc bIntElastUnc TmatUnc TsqmatUnc coefmat2st TotElast2st ExtElast2st IntElast2st bTotElast2st bExtElast2st bIntElast2st Tmat2st Tsqmat2st xmrmat prbdlnw bElast2st bElast2st;

capture program drop sureboth;
capture program drop calcelast2st;


log close;
cd "$root";
