*! version 1.2.2  25sep2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 400m
set matsize 400
set more off
capture log close

capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf"
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf/cafege"

cd "$rootslct"
log using "logs/xtivreg-cafege-ext-pt$par-af$aff-allyrs.log", replace

mat drop _all

adopath + "$root/%stata/ado"


/* region-level IVs */
/*------------------*/

* WTF IVs (one-year lags)
tempfile wtfprox lgwtfprx wtf37
use "$root/trade/wtf-fdiproxies-1989-2000", clear //  ===in USD billion, US-CPI deflated to base year 1998===
* transform to ===EUR million, base year 1998===
local idvars "nace11 year"
unab allvars : *
unab relvars : rdl1_*
unab logvars : ln_*
local remvars : list idvars | relvars 
local remvars : list remvars | logvars
local genvars : list allvars - remvars
foreach v of local genvars {
  replace `v' = `v' * 1000 / 1.17499  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
foreach v of local logvars {
  replace `v' = `v' + log(1000) - log(1.17499)  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
drop dl1_* rdl1_* ln_*
rename nace11 nace1
preserve
  collapse (mean) vfdi* hfdi* expfdi*, by(year)  // use annual mean of all sectors for sector 37
  gen byte nace1 = 37
  sort nace1 year
  save `wtf37'
restore
append using `wtf37'
sort nace1 year
save `wtfprox'
replace year = year + 1  // for one-year lags (level regressions)
foreach var in vfdi_oecd hfdi_oecd expfdi {
  egen `var'_DEV = rsum(`var'_APC `var'_ODV `var'_RCA)
  egen `var'_WEU = rsum(`var'_EMU `var'_OWE)
  drop `var'_APC `var'_EMU `var'_ODV `var'_OWE `var'_RCA
  }
label var vfdi_oecd_DEV "DEV Exports to OECD (excl. D)"
label var hfdi_oecd_DEV "DEV Imports from OECD (excl. D)"
label var expfdi_DEV "DEV Exp. to neighbors (excl. D)"
label var vfdi_oecd_WEU "WEU Exports to OECD (excl. D)"
label var hfdi_oecd_WEU "WEU Imports from OECD (excl. D)"
label var expfdi_WEU "WEU Exp. to neighbors (excl. D)"
order nace1 year vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
sort nace1 year
save `lgwtfprx'


/* level regressions */
/*-------------------*/

/* data */

use "Xdata/data-parent-hostregion-pt$par-af$aff-allyrs", clear
gen prft_eqty_par = profits_par/equity_par
label var prft_eqty_par "Profits/equity parent"
gen byte ind_exp_par = (exports_par>0 & exports_par~=.)
label var ind_exp_par "Indic.: Exports parent"
gen byte _mcmpvar = .
gen byte _mwage = .
order firmid year ustan nace1 sec1_bem sec1_aggbem employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par prft_eqty_par ind_exp_par
foreach year in 1996 1997 1998 1999 2000 2001 {
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-competitor-exposure-`year'-$waglvl-pt$par-af$aff", update
  drop if firmid==0
  replace _mcmpvar = _merge if _merge==3 | _merge==4
  drop _merge
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-wages-`year'-$waglvl", update
  replace _mwage = _merge if _merge==3 | _merge==4
  drop _merge
  }
tab _mcmpvar
qui count if _mcmpvar ~=3 & _mcmpvar ~=4
if `r(N)'>0  STOP  // matching error
drop _mcmpvar
tab _mwage
qui count if _mwage ~=3 & _mwage ~=4 & _mwage~=.
if `r(N)'>0  STOP  // matching error
drop _mwage

sort nace1 year
merge nace1 year using `lgwtfprx', nokeep
qui count if _merge ~=3
if `r(N)'>0  STOP  // matching error
drop _m

table nace1 year, c(mean employmt_par)
table nace1 year, c(mean employmt_CEE)
table nace1 year, c(mean cmpt_employmt_CEE)
table nace1 year, c(mean w_CEE)
drop if nace1==37  // remove sector with scattered observations

* variable resetting
tabulate year, generate(indyr)
drop indyr1  // omitted year
tsset, clear
drop profits_par wb_* fixdasst_* assettot_* cmpt_wb_* cmpt_fixdasst_*


/* LEVEL REGRESSIONS */
desc

* employment, OLS and 2SLS

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU
est2vec iv_empl, vars(equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec iv_empl, r(F p df df_r) name(ols_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_empl, addto(iv_empl) name(iv_empl_now)
est2vec iv_empl, raddto(iv_empl) name(iv_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU)
est2vec iv_empl, addto(iv_empl) name(iv_empl)
est2vec iv_empl, raddto(iv_empl) name(iv_empl)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*
est2vec iv_empl, addto(iv_empl) name(xtyr_empl)
est2vec iv_empl, raddto(iv_empl) name(xtyr_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_empl, addto(iv_empl) name(xtivyr_empl_now)
est2vec iv_empl, raddto(iv_empl) name(xtivyr_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_empl, addto(iv_empl) name(xtivyr_empl)
est2vec iv_empl, raddto(iv_empl) name(xtivyr_empl)

foreach reg in $regagg {
  reg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec iv_empl, raddto(iv_empl) name(iv1_empl_`reg')
  reg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec iv_empl, raddto(iv_empl) name(iv1_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_iv_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, OLS and 2SLS

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU
est2vec iv_turnov, vars(equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_turnov)
est2vec iv_turnov, r(F p df df_r) name(ols_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_turnov, addto(iv_turnov) name(iv_turnov_now)
est2vec iv_turnov, raddto(iv_turnov) name(iv_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU)
est2vec iv_turnov, addto(iv_turnov) name(iv_turnov)
est2vec iv_turnov, raddto(iv_turnov) name(iv_turnov)

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*
est2vec iv_turnov, addto(iv_turnov) name(xtyr_turnov)
est2vec iv_turnov, raddto(iv_turnov) name(xtyr_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_turnov, addto(iv_turnov) name(xtivyr_turnov_now)
est2vec iv_turnov, raddto(iv_turnov) name(xtivyr_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_turnov, addto(iv_turnov) name(xtivyr_turnov)
est2vec iv_turnov, raddto(iv_turnov) name(xtivyr_turnov)

foreach reg in $regagg {
  reg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec iv_turnov, raddto(iv_turnov) name(iv1_turnov_`reg')
  reg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec iv_turnov, raddto(iv_turnov) name(iv1_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_iv_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, sector (sec1_bem) level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_empl, vars(equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_empl)
est2vec xtivsec_empl, r(F p df df_r) name(xtsec_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_empl, addto(xtivsec_empl) name(xtivsec_empl_now)
est2vec xtivsec_empl, raddto(xtivsec_empl) name(xtivsec_emp_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_empl, addto(xtivsec_empl) name(xtivsec_empl)
est2vec xtivsec_empl, raddto(xtivsec_empl) name(xtivsec_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivsec_empl, raddto(xtivsec_empl) name(xt1sec_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivsec_empl, raddto(xtivsec_empl) name(xt1sec_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, sector (sec1_bem) level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_turnov, vars(equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_turnov)
est2vec xtivsec_turnov, r(F p df df_r) name(xtsec_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_turnov, addto(xtivsec_turnov) name(xtivsec_turnov_now)
est2vec xtivsec_turnov, raddto(xtivsec_turnov) name(xtivsec_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_turnov, addto(xtivsec_turnov) name(xtivsec_turnov)
est2vec xtivsec_turnov, raddto(xtivsec_turnov) name(xtivsec_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivsec_turnov, raddto(xtivsec_turnov) name(xt1sec_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivsec_turnov, raddto(xtivsec_turnov) name(xt1sec_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, firm level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(firmid)
est2vec xtivfrm_empl, vars(equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_empl)
est2vec xtivfrm_empl, r(F p df df_r) name(xtfrm_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_empl, addto(xtivfrm_empl) name(xtivfrm_empl_now)
est2vec xtivfrm_empl, raddto(xtivfrm_empl) name(xtivfrm_empl_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_empl, addto(xtivfrm_empl) name(xtivfrm_empl)
est2vec xtivfrm_empl, raddto(xtivfrm_empl) name(xtivfrm_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivfrm_empl, raddto(xtivfrm_empl) name(xt1frm_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivfrm_empl, raddto(xtivfrm_empl) name(xt1frm_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, firm level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(firmid)
est2vec xtivfrm_turnov, vars(equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_turnov)
est2vec xtivfrm_turnov, r(F p df df_r) name(xtfrm_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_turnov, addto(xtivfrm_turnov) name(xtivfrm_turnov_now)
est2vec xtivfrm_turnov, raddto(xtivfrm_turnov) name(xtivfrm_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_turnov, addto(xtivfrm_turnov) name(xtivfrm_turnov)
est2vec xtivfrm_turnov, raddto(xtivfrm_turnov) name(xtivfrm_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivfrm_turnov, raddto(xtivfrm_turnov) name(xt1frm_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_HOM w_CEE w_DEV w_OIN w_WEU
  est2vec xtivfrm_turnov, raddto(xtivfrm_turnov) name(xt1frm_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


/* LOG-LEVEL REGRESSIONS */

* variable resetting to logs
replace employmt_par = ln(employmt_par)
label var employmt_par "Log Employment parent [thsd]"
replace turnover_par = ln(turnover_par)
label var turnover_par "Log Turnover parent [thsd]"
replace equity_par = ln(equity_par)
label var equity_par "Log Equity parent [thsd]"
replace liab_par = ln(liab_par)
label var liab_par "Log Debt parent [thsd]"
replace exports_par = ln(exports_par)
replace exports_par = 0 if ind_exp_par==0
label var exports_par "Log Exports parent [thsd]"
foreach reg in $regagg {
  gen byte ind_empl_`reg' = (employmt_`reg'>0 & employmt_`reg'~=.)
  label var ind_empl_`reg' "Indic.: Employment `reg'"
  gen byte ind_turnov_`reg' = (turnover_`reg'>0 & turnover_`reg'~=.)
  label var ind_turnov_`reg' "Indic.: Turnover `reg'"
  replace employmt_`reg' = ln(employmt_`reg')
  replace employmt_`reg' = 0 if ind_empl_`reg'==0
  label var employmt_`reg' "Log Employment `reg'"
  replace turnover_`reg' = ln(turnover_`reg')
  replace turnover_`reg' = 0 if ind_turnov_`reg'==0
  label var turnover_`reg' "Log Turnover [ppp] `reg'"
  replace cmpt_employmt_`reg' = ln(cmpt_employmt_`reg')
  label var cmpt_employmt_`reg' "Log Cmpt'r Employment `reg'"
  replace cmpt_turnover_`reg' = ln(cmpt_turnover_`reg')
  label var cmpt_turnover_`reg' "Log Cmpt'r Turnover [ppp] `reg'"
  }
replace cmpt_employmt_HOM = ln(cmpt_employmt_HOM)
label var cmpt_employmt_HOM "Log Cmpt'r Employment HOM"
replace cmpt_turnover_HOM = ln(cmpt_turnover_HOM)
label var cmpt_turnover_HOM "Log Cmpt'r Turnover [ppp] HOM"
desc


* log employment, OLS and 2SLS

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU
est2vec iv_lnempl, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec iv_lnempl, r(F p df df_r) name(ols_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par (ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_lnempl, addto(iv_lnempl) name(iv_empl)
est2vec iv_lnempl, raddto(iv_lnempl) name(iv_empl)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*
est2vec iv_lnempl, addto(iv_lnempl) name(xtyr_empl)
est2vec iv_lnempl, raddto(iv_lnempl) name(xtyr_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_lnempl, addto(iv_lnempl) name(xtivyr_empl)
est2vec iv_lnempl, raddto(iv_lnempl) name(xtivyr_empl)

foreach reg in $regagg {
  reg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_lnempl, raddto(iv_lnempl) name(iv1_empl_`reg')
  reg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_lnempl, raddto(iv_lnempl) name(iv1_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_iv_lnempl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* log turnover, OLS and 2SLS

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU
est2vec iv_lnturnov, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_turnov)
est2vec iv_lnturnov, r(F p df df_r) name(ols_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par (ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_lnturnov, addto(iv_lnturnov) name(iv_turnov)
est2vec iv_lnturnov, raddto(iv_lnturnov) name(iv_turnov)

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*
est2vec iv_lnturnov, addto(iv_lnturnov) name(xtyr_turnov)
est2vec iv_lnturnov, raddto(iv_lnturnov) name(xtyr_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_lnturnov, addto(iv_lnturnov) name(xtivyr_turnov)
est2vec iv_lnturnov, raddto(iv_lnturnov) name(xtivyr_turnov)

foreach reg in $regagg {
  reg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_lnturnov, raddto(iv_lnturnov) name(iv1_turnov_`reg')
  reg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_lnturnov, raddto(iv_lnturnov) name(iv1_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_iv_lnturnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* log employment, sector (sec1_bem) level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_lnempl, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_empl)
est2vec xtivsec_lnempl, r(F p df df_r) name(xtsec_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_lnempl, addto(xtivsec_lnempl) name(xtivsec_empl)
est2vec xtivsec_lnempl, raddto(xtivsec_lnempl) name(xtivsec_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivsec_lnempl, raddto(xtivsec_lnempl) name(xt1sec_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivsec_lnempl, raddto(xtivsec_lnempl) name(xt1sec_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_lnempl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* log turnover, sector (sec1_bem) level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_lnturnov, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_turnov)
est2vec xtivsec_lnturnov, r(F p df df_r) name(xtsec_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_lnturnov, addto(xtivsec_lnturnov) name(xtivsec_turnov)
est2vec xtivsec_lnturnov, raddto(xtivsec_lnturnov) name(xtivsec_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivsec_lnturnov, raddto(xtivsec_lnturnov) name(xt1sec_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivsec_lnturnov, raddto(xtivsec_lnturnov) name(xt1sec_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_lnturnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* log employment, firm level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(firmid)
est2vec xtivfrm_lnempl, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_empl)
est2vec xtivfrm_lnempl, r(F p df df_r) name(xtfrm_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_lnempl, addto(xtivfrm_lnempl) name(xtivfrm_empl)
est2vec xtivfrm_lnempl, raddto(xtivfrm_lnempl) name(xtivfrm_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivfrm_lnempl, raddto(xtivfrm_lnempl) name(xt1frm_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivfrm_lnempl, raddto(xtivfrm_lnempl) name(xt1frm_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_empl_CEE employmt_CEE ind_empl_DEV employmt_DEV ind_empl_OIN employmt_OIN ind_empl_WEU employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_lnempl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* log turnover, firm level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(firmid)
est2vec xtivfrm_lnturnov, vars(equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_turnov)
est2vec xtivfrm_lnturnov, r(F p df df_r) name(xtfrm_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* (ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_lnturnov, addto(xtivfrm_lnturnov) name(xtivfrm_turnov)
est2vec xtivfrm_lnturnov, raddto(xtivfrm_lnturnov) name(xtivfrm_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivfrm_lnturnov, raddto(xtivfrm_lnturnov) name(xt1frm_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec xtivfrm_lnturnov, raddto(xtivfrm_lnturnov) name(xt1frm_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par exports_par ind_turnov_CEE turnover_CEE ind_turnov_DEV turnover_DEV ind_turnov_OIN turnover_OIN ind_turnov_WEU turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_lnturnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* save matrices *

foreach type in b se e r {
  drop _all
  matsave iv_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_lnempl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_lnturnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_lnempl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_lnturnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_lnempl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_lnturnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  }

log close
cd "$root"
